<?php

/**
 * @package    VP Email Manager
 * @copyright  Copyright (C) 2012-2024 VirtuePlanet Services LLP. All rights reserved.
 * @license    GNU General Public License version 3 or later; see LICENSE.txt
 * @author     Abhishek Das <info@virtueplanet.com>
 * @link       https://www.virtueplanet.com
 *
 * @phpcs:disable PSR1.Classes.ClassDeclaration.MissingNamespace
 */

use Joomla\CMS\Application\CMSApplication;
use Joomla\CMS\Factory;

// phpcs:disable PSR1.Files.SideEffects
defined('_JEXEC') or die;
// phpcs:enable PSR1.Files.SideEffects

/**
 * Event controller class.
 */
class VpemControllerEvent extends \Joomla\CMS\MVC\Controller\FormController
{
    /**
     * Constructor
     *
     * @throws Exception
     */
    public function __construct()
    {
        $this->view_list = 'events';

        parent::__construct();
    }

    public function setType()
    {
        // Check for request forgeries.
        $this->checkToken();

        /** @var CMSApplication $app */
        $app = Factory::getApplication();

        /** @var VpemModelEvent $model */
        $model   = $this->getModel();
        $table   = $model->getTable();
        $data    = $this->input->post->get('jform', [], 'ARRAY');
        $checkin = property_exists($table, $table->getColumnAlias('checked_out'));
        $context = "$this->option.edit.$this->context";

        // Determine the name of the primary key for the data.
        if (empty($key)) {
            $key = $table->getKeyName();
        }

        // To avoid data collisions the urlVar may be different from the primary key.
        if (empty($urlVar)) {
            $urlVar = $key;
        }

        $recordId = $this->input->getInt($urlVar);

        // Populate the row id from the session.
        $data[$key] = $recordId;

        $form = $model->getForm($data, false);

        /**
         * We need the filtered value of calendar fields because the UTC normalision is
         * done in the filter and on output. This would apply the Timezone offset on
         * reload. We set the calendar values we save to the processed date.
         */
        $filteredData = $form->filter($data);

        foreach ($form->getFieldset() as $field) {
            if ($field->type === 'Calendar') {
                $fieldName = $field->fieldname;

                if (isset($filteredData[$fieldName])) {
                    $data[$fieldName] = $filteredData[$fieldName];
                }
            }
        }

        // Save the data in the session.
        $app->setUserState($context . '.data', $data);

        // Redirect back to the edit screen.
        $this->setRedirect(
            \JRoute::_(
                'index.php?option=' . $this->option . '&view=' . $this->view_item
                    . $this->getRedirectToItemAppend($recordId, $urlVar),
                false
            )
        );
    }
}
