<?php
/**
 * @version    CVS: 1.0
 * @package    Com_Vpem
 * @author     Abhishek Das <info@virtueplanet.com>
 * @copyright  Copyright (C) 2012-2024 VirtuePlanet Services LLP. All rights reserved.
 * @license    GNU General Public License version 3 or later; see LICENSE.txt
 */

// No direct access
defined('_JEXEC') or die;

/**
 * Template controller class.
 *
 * @since  1.6
 */
class VpemControllerTemplate extends \Joomla\CMS\MVC\Controller\FormController
{
	public function getStyle()
	{
		$this->checkToken('GET');
		
		$model   = $this->getModel();
		$pk      = $this->input->getInt('id', null);
		$item    = $model->getItem($pk);
		$app     = JFactory::getApplication();
		$obLevel = ob_get_level();
		
		if ($obLevel)
		{
			while ($obLevel > 0)
			{
				ob_end_clean();
				$obLevel --;
			}
		}
		else
		{
			ob_clean();
		}
		
		header('Content-type: application/text');
		header('Content-type: text/css');
		header('Cache-Control: public,max-age=1,must-revalidate');
		header('Expires: ' . gmdate('D, d M Y H:i:s', ($_SERVER['REQUEST_TIME'] + 1)) . ' GMT');
		header('Last-modified: ' . gmdate('D, d M Y H:i:s', $_SERVER['REQUEST_TIME']) . ' GMT');
		
		if (function_exists('header_remove')) 
		{
			header_remove('Pragma');
		}
		
		echo $item->css_style;
		
		flush();
		$app->close();
	}
	
	public function getPreview()
	{
		$this->checkToken('GET');
		
		$params   = JComponentHelper::getParams('com_vpem');
		$model    = $this->getModel();
		$pk       = $this->input->getInt('id', null);
		$item     = $model->getItem($pk);
		$errorMsg = '';
		
		VmConfig::loadJLang('com_virtuemart');
		VmConfig::loadJLang('com_virtuemart', true);
		VmConfig::loadJLang('com_virtuemart_shoppers', true);
		
		if (strpos($item->type, 'order') !== false)
		{
			$preview_order_id = (int) $params->get('preview_order_id', 0);
			
			if (empty($preview_order_id))
			{
				$errorMsg = JText::_('COM_VPEM_ERROR_SET_PREVIEW_ORDER');
			}
			else
			{
				$item = VpemHelper::renderOrderEmail($preview_order_id, $item, true, true);
			}
			
			if (empty($item))
			{
				$errorMsg = JText::_('COM_VPEM_ERROR_SET_PREVIEW_ORDER');
			}
		}
		elseif (strpos($item->type, 'user') !== false)
		{
			$preview_user_id = (array) $params->get('preview_user_id', []);
			
			if (empty($preview_user_id))
			{
				$errorMsg = JText::_('COM_VPEM_ERROR_SET_PREVIEW_USER');
			}
			else
			{
				$preview_user_id = array_filter(array_map('intval', $preview_user_id));
				$item = VpemHelper::renderUserEmail($preview_user_id[0], $item, true, true);
			}
			
			if (empty($item))
			{
				$errorMsg = JText::_('COM_VPEM_ERROR_SET_PREVIEW_USER');
			}
		}
		elseif (strpos($item->type, 'question') !== false)
		{
			$preview_product_id = (array) $params->get('preview_product_id', []);
			
			if (empty($preview_product_id))
			{
				$errorMsg = JText::_('COM_VPEM_ERROR_SET_PREVIEW_PRODUCT');
			}
			else
			{
				$preview_product_id = array_filter(array_map('intval', $preview_product_id));
				$item = VpemHelper::renderProductQuestionEmail($preview_product_id[0], $item, true);
			}
			
			if (empty($item))
			{
				$errorMsg = JText::_('COM_VPEM_ERROR_SET_PREVIEW_PRODUCT');
			}
		}
		elseif (strpos($item->type, 'notification') !== false)
		{
			$preview_product_id = (array) $params->get('preview_product_id', []);
			
			if (empty($preview_product_id))
			{
				$errorMsg = JText::_('COM_VPEM_ERROR_SET_PREVIEW_PRODUCT');
			}
			else
			{
				$preview_product_id = array_filter(array_map('intval', $preview_product_id));
				$item = VpemHelper::renderProductNotifyEmail($preview_product_id[0], $item, true);
			}
			
			if (empty($item))
			{
				$errorMsg = JText::_('COM_VPEM_ERROR_SET_PREVIEW_PRODUCT');
			}
		}
		elseif (strpos($item->type, 'recommend') !== false)
		{
			$preview_user_id = (array) $params->get('preview_user_id', []);
			
			if (empty($preview_user_id))
			{
				$errorMsg = JText::_('COM_VPEM_ERROR_SET_PREVIEW_USER');
			}
			
			$preview_product_id = (array) $params->get('preview_product_id', []);
			
			if (empty($preview_product_id))
			{
				$errorMsg = JText::_('COM_VPEM_ERROR_SET_PREVIEW_PRODUCT');
			}
			else
			{
				$preview_product_id = array_filter(array_map('intval', $preview_product_id));
				$item = VpemHelper::renderProductRecommendEmail($preview_product_id[0], $item, true);
			}
			
			if (empty($item))
			{
				$errorMsg = JText::_('COM_VPEM_ERROR_SET_PREVIEW_PRODUCT');
			}
		}
		
		if ($errorMsg)
		{
			echo JLayoutHelper::render('error_message', ['error_message' => $errorMsg], null, array('client' => 'admin', 'component' => 'com_vpem'));
		}
		else
		{
			echo $item->body;
		}
		
		JFactory::getApplication()->close();
	}
}
