<?php

/**
 * @package    VP Email Manager
 * @copyright  Copyright (C) 2012-2024 VirtuePlanet Services LLP. All rights reserved.
 * @license    GNU General Public License version 3 or later; see LICENSE.txt
 * @author     Abhishek Das <info@virtueplanet.com>
 * @link       https://www.virtueplanet.com
 *
 * @phpcs:disable PSR1.Classes.ClassDeclaration.MissingNamespace
 */

use Joomla\CMS\Factory;
use Joomla\Registry\Registry;
use Joomla\CMS\Language\Text;

// phpcs:disable PSR1.Files.SideEffects
defined('_JEXEC') or die;

JLoader::register('VpemHelperOrder', __DIR__ . '/order.php');
JLoader::register('VpemHelperMustache', __DIR__ . '/mustache.php');
JLoader::register('VpemHelperOrderdata', __DIR__ . '/orderdata.php');
JLoader::register('VpemHelperProductdata', __DIR__ . '/productdata.php');
JLoader::register('VpemHelperOrderitem', __DIR__ . '/orderitem.php');
JLoader::register('VpemHelperRenderer', __DIR__ . '/renderer.php');
// phpcs:enable PSR1.Files.SideEffects

/**
 * Vpem helper.
 */
class VpemHelper
{
    /**
     * Configure the Linkbar.
     *
     * @param   string  $vName  string
     *
     * @return void
     */
    public static function addSubmenu($vName = '')
    {
        JHtmlSidebar::addEntry(Text::_('COM_VPEM_TITLE_EVENTS'), 'index.php?option=com_vpem&view=events', $vName == 'events');
        JHtmlSidebar::addEntry(Text::_('COM_VPEM_TITLE_TEMPLATES'), 'index.php?option=com_vpem&view=templates', $vName == 'templates');
        JHtmlSidebar::addEntry(Text::_('COM_VPEM_TITLE_OUTBOX'), 'index.php?option=com_vpem&view=outbox', $vName == 'outbox');
    }

    public static function sendMail($viewName, $view, $recipient, $noVendorMail = false, $eventId = null)
    {
        $params      = JComponentHelper::getParams('com_vpem');
        $emails      = null;
        $triggerType = null;
        $app         = Factory::getApplication();

        // Bypass VP Email Manager
        if (!$params->get('enable', 1)) {
            return false;
        }

        // Order mail
        if ($viewName === 'invoice') {
            $pendingStatusExists    = false;
            $isConfirmedOrder       = false;
            $pendingOrderStatuses   = (array) $params->get('pending_order_status', ['P']);
            $confirmedOrderStatuses = (array) $params->get('confirm_order_status', ['C', 'U']);

            if (!empty($view->orderDetails['history'])) {
                foreach ($view->orderDetails['history'] as $history) {
                    if (in_array($history->order_status_code, $pendingOrderStatuses)) {
                        $pendingStatusExists = true;

                        break;
                    }
                }

                $currentHistory = end($view->orderDetails['history']);

                reset($view->orderDetails['history']);

                if (in_array($currentHistory->order_status_code, $confirmedOrderStatuses)) {
                    $isConfirmedOrder = true;
                } elseif (isset($view->newOrderData['order_status']) && in_array($view->newOrderData['order_status'], $confirmedOrderStatuses)) {
                    $isConfirmedOrder = true;
                }
            }

            if (isset($view->newOrderData['order_status']) && isset($view->newOrderData['current_order_status']) && (count($view->orderDetails['history']) > 2 || (!$pendingStatusExists && count($view->orderDetails['history']) >= 1))) {
                if (!$noVendorMail) {
                    if (property_exists($view, 'doVendor') && $view->doVendor) {
                        // Send order status change notification to vendor
                        $triggerType = 'admin_order_status_change';
                    } else {
                        // Send order status change notification to shopper
                        $triggerType = 'order_status_change';
                    }
                } else {
                    // Send order status change notification to vendor
                    $triggerType = 'admin_order_status_change';
                }
            } else {
                if ($isConfirmedOrder) {
                    if (!$noVendorMail) {
                        if (property_exists($view, 'doVendor') && $view->doVendor) {
                            // Send order confirmation notification to vendor
                            $triggerType = 'admin_order_confirmation';
                        } else {
                            // Send order confirmation notification to shopper
                            $triggerType = 'order_confirmation';
                        }
                    } else {
                        // Send order confirmation notification to vendor
                        $triggerType = 'admin_order_confirmation';
                    }
                } else {
                    if (!$noVendorMail) {
                        if (property_exists($view, 'doVendor') && $view->doVendor) {
                            // Send order status change notification to vendor
                            $triggerType = 'admin_order_status_change';
                        } else {
                            // Send order status change notification to shopper
                            $triggerType = 'order_status_change';
                        }
                    } else {
                        // Send order status change notification to vendor
                        $triggerType = 'admin_order_status_change';
                    }
                }
            }

            if ($triggerType) {
                $emails = self::renderOrderEmails($view->orderDetails['details']['BT']->virtuemart_order_id, $triggerType, $eventId);

                vRequest::setVar('doVendor', $noVendorMail);

                $attach = (string) VmConfig::get('attach', '');

                if (empty($view->mediaToSend)) {
                    $view->mediaToSend = [];
                }

                $attach_os = VmConfig::get('attach_os', []);
                $attach_os = !is_array($attach_os) ? [$attach_os] : $attach_os;
                $attach_os = array_filter($attach_os);

                if (!empty($attach) && !$noVendorMail && in_array($view->orderDetails['details']['BT']->order_status, $attach_os)) {
                    $attachment = explode(',', $attach);

                    foreach ($attachment as $file) {
                        $view->mediaToSend[] = VMPATH_ROOT . '/' . VmConfig::get('media_vendor_path', '') . '/' . trim($file);
                    }
                }
            }
        } elseif ($viewName === 'order_followup') { // Send order followup mail.
            $triggerType = 'order_followup';

            $emails = self::renderOrderEmails($view->virtuemart_order_id, $triggerType, $eventId);
        } elseif ($viewName === 'user') { // User registration mail
            if (property_exists($view, 'user')) {
                if (!property_exists($view, 'password')) {
                    $view->password = '';
                }

                $usersParams = JComponentHelper::getParams('com_users');

                if (!$noVendorMail) {
                    $triggerType = 'user_registration';
                } else {
                    // Do not send admin notification
                    if (!$usersParams->get('mail_to_admin', 1)) {
                        return true;
                    }

                    $triggerType = 'admin_user_registration';

                    if (empty($recipient)) {
                        $db = Factory::getDbo();
                        $query = $db->getQuery(true);

                        $query->select($db->quoteName('email'))
                            ->from($db->quoteName('#__users'))
                            ->where($db->quoteName('sendEmail') . ' = 1')
                            ->where($db->quoteName('block') . ' = 0');

                        $db->setQuery($query);

                        try {
                            $recipient = $db->loadColumn();
                        } catch (RuntimeException $e) {
                            vmError(Text::sprintf('COM_USERS_DATABASE_ERROR', $e->getMessage()), 500);
                            return true;
                        }
                    }
                }

                $emails = self::renderUserEmails($view, $triggerType);
            }
        } elseif ($viewName === 'productdetails') { // User notification mail
            if (property_exists($view, 'productName') && property_exists($view, 'link')) {
                $triggerType = 'product_notification';

                $emails = self::renderProductNotifyEmails($view, $triggerType);
            }
        } elseif ($viewName === 'askquestion') { // Ask a question mail
            if (property_exists($view, 'product')) {
                $triggerType = 'admin_ask_a_question';

                $emails = self::renderProductQuestionEmails($view, $triggerType);
            }
        } elseif ($viewName === 'recommend') { // Ask a question mail
            $triggerType = 'recommend_product';

            $emails = self::renderProductRecommendEmails($view, $triggerType);
        }

        if (!empty($emails)) {
            foreach ($emails as $email) {
                // Send emails one by one
                $mailer   = Factory::getMailer();
                $sentData = [
                    'type' => $triggerType,
                    'attachments' => []
                ];

                if (strpos($email->type, 'admin') !== false && !empty($email->mail_to)) {
                    $sentData['mail_to'] = $email->mail_to;
                    $email->mail_to      = strpos($email->mail_to, ',') !== false ? explode(',', $email->mail_to) : $email->mail_to;

                    $mailer->addRecipient($email->mail_to);
                } else {
                    $sentData['mail_to'] = $recipient;

                    $mailer->addRecipient($recipient);
                }

                if (!empty($email->mail_cc)) {
                    $sentData['cc'] = $email->mail_cc;
                    $email->mail_cc = strpos($email->mail_cc, ',') !== false ? explode(',', $email->mail_cc) : $email->mail_cc;

                    $mailer->addCc($email->mail_cc);
                }

                if (!empty($email->mail_bcc)) {
                    $sentData['bcc'] = $email->mail_bcc;
                    $email->mail_bcc = strpos($email->mail_bcc, ',') !== false ? explode(',', $email->mail_bcc) : $email->mail_bcc;

                    $mailer->addBcc($email->mail_bcc);
                }

                $sentData['subject'] = $email->subject;
                $sentData['body']    = $email->body;
                $replyTo             = [];
                $replyToName         = [];
                $sender              = [];

                // $subject             = '=?utf-8?B?' . base64_encode($email->subject) . '?=';
                // $subject             = html_entity_decode($subject, ENT_QUOTES, 'UTF-8');

                $mailer->CharSet = 'UTF-8';

                $mailer->setSubject($email->subject);
                $mailer->isHTML(true);
                $mailer->setBody($email->body);

                if (!$noVendorMail) {
                    $vendorModel = VmModel::getModel('vendor');

                    if (!property_exists($view, 'vendorEmail') || empty($view->vendorEmail)) {
                        $view->vendorEmail = $vendorModel->getVendorEmail(1);
                    }

                    if (!property_exists($view, 'vendor') || empty($view->vendor)) {
                        $view->vendor = $vendorModel->getVendor(1);
                    }

                    $replyTo[0]     = $view->vendorEmail;
                    $replyToName[0] = $view->vendor->vendor_name;
                } else {
                    if (property_exists($view, 'orderDetails') && isset($view->orderDetails['details']) && isset($view->orderDetails['details']['BT'])) {
                        $replyTo[0]     = $view->orderDetails['details']['BT']->email;
                        $replyToName[0] = $view->orderDetails['details']['BT']->first_name . ' ' . $view->orderDetails['details']['BT']->last_name;
                    } elseif (property_exists($view, 'user')) {
                        if (is_object($view->user) && !empty($view->user->email)) {
                            $replyTo[0]     = $view->user->email;
                            $replyToName[0] = isset($view->user->name) ?  $view->user->name : false;
                        } elseif (is_array($view->user) && !empty($view->user['email'])) {
                            $replyTo[0]     = $view->user['email'];
                            $replyToName[0] = isset($view->user['name']) ? $view->user['name'] : false;
                        }
                    }
                }

                if (in_array($email->type, ['order_confirmation', 'order_status_change', 'order_followup', 'user_registration', 'product_notification'])) {
                    if (!empty($email->reply_to)) {
                        $replyTo[0] = $email->reply_to;
                    }

                    if (!empty($email->reply_to_name)) {
                        $replyToName[0] = $email->reply_to_name;
                    }
                }

                if (!empty($replyTo)) {
                    $sentData['reply_to']      = $replyTo[0];
                    $sentData['reply_to_name'] = $replyToName[0];

                    if (version_compare(JVERSION, '3.5', 'ge')) {
                        $mailer->addReplyTo($replyTo, $replyToName);
                    } else {
                        $replyTo[1] = $replyToName[0];

                        $mailer->addReplyTo($replyTo);
                    }
                }

                if (!empty($email->mail_form) && !empty($email->mail_from_name)) {
                    $sender[0] = $email->mail_form;
                    $sender[1] = $email->mail_from_name;
                } else {
                    $config = Factory::getConfig();

                    $sender[0] = $config->get('mailfrom');
                    $sender[1] = $config->get('fromname');
                }

                $sentData['mail_from'] = $sender[0];
                $sentData['from_name'] = $sender[1];

                $mailer->setSender($sender);

                if (!empty($email->attachments)) {
                    $attachmentDir = JPATH_SITE . '/media/com_vpem/attachments';
                    $attachmentDir = $params->get('attachment_dir', $attachmentDir);
                    $attachmentDir = JPath::clean($attachmentDir);

                    foreach ($email->attachments as $filename) {
                        $attachmentFile = JPath::clean($attachmentDir . DIRECTORY_SEPARATOR . $filename);

                        if (is_file($attachmentFile)) {
                            $mailer->addAttachment($attachmentFile);

                            $sentData['attachments'][] = $attachmentFile;
                        }
                    }
                }

                if (!empty($view->mediaToSend)) {
                    foreach ((array) $view->mediaToSend as $media) {
                        $mailer->addAttachment($media);

                        $sentData['attachments'][] = $media;
                    }
                }

                try {
                    $sentData['status'] = $mailer->Send();
                } catch (Exception $e) {
                    // Log error
                    $sentData['error_message'] = $e->getMessage();
                    $sentData['status'] = false;
                }

                // Save sentData
                JModelLegacy::addIncludePath(JPATH_ADMINISTRATOR . '/components/com_vpem/models');
                JModelLegacy::addTablePath(JPATH_ADMINISTRATOR . '/components/com_vpem/tables');

                /** @var VpemModelMail $model */
                $model = JModelLegacy::getInstance('Mail', 'VpemModel', ['ignore_request' => true]);

                if (!$model->save($sentData)) {
                    $app->enqueueMessage($model->getError(), 'error');
                }
            }

            if (!empty($view->mediaToSend)) {
                $view->mediaToSend = [];
            }

            return true;
        }

        // For order followup we need to save the email status and try again afterwards.
        // Core VirtueMart email will be sent as fallback.
        if ($viewName === 'order_followup' || $params->get('fallback', 1)) {
            return false;
        }

        return true;
    }

    public static function renderProductNotifyEmails($view, $type = 'product_notification')
    {
        $events = self::getEvents($type);

        if (empty($events)) {
            return false;
        }

        foreach ($events as &$event) {
            if (!empty($event->language) && $event->language != '*' && !empty(VmConfig::$vmlangTag)) {
                if (VmConfig::$vmlangTag != $event->language) {
                    continue;
                }
            }

            if (!self::renderProductNotifyEmail($view, $event, false)) {
                return false;
            }
        }

        return $events;
    }

    public static function renderProductNotifyEmail($view, &$email, $isPreview = false)
    {
        $productModel = VmModel::getModel('product');

        // Load site language.
        self::loadLanguage();

        if (is_numeric($view)) {
            $product_id        = (int) $view;
            $view              = new stdClass();
            $product           = $productModel->getProduct($product_id);
            $view->productName = $product->product_name;
            $app               = Factory::getApplication();

            /** @disregard P1009 */
            $isAdmin  = method_exists($app, 'isClient') ? !$app->isClient('site') : $app->isAdmin();

            if ($isAdmin) {
                $url = JUri::root() . 'index.php?option=com_virtuemart&view=productdetails&virtuemart_product_id=' . $product->virtuemart_product_id;
            } else {
                $url = JRoute::_('index.php?option=com_virtuemart&view=productdetails&virtuemart_product_id=' . $product->virtuemart_product_id, true, false, true);
            }

            $view->link = '<a href="' . $url . '" target="_blank">' . $product->product_name . '</a>';
        }

        $viewData = [
            'product_name' => $view->productName,
            'product_link' => $view->link,
            'mail_body'    => !empty($view->mailbody) ? nl2br($view->mailbody) : ''
        ];

        if (!empty($view->subject) && !empty($view->mailbody)) {
            $email->subject = $view->subject;
        }

        $renderer = VpemHelperRenderer::getInstance();
        $mustache = $renderer->getMustache();

        $data = new VpemHelperProductdata($viewData, $mustache);

        if (!$renderer->renderMail($data, $email->subject, $email->body, $mustache)) {
            // TODO: Log error

            return false;
        }

        if ($isPreview) {
            $email->preview_subject = $email->subject;
        }

        $email->body = self::renderBody($email);

        return $email;
    }

    public static function renderProductRecommendEmails($view, $type = 'recommend_product')
    {
        $events = self::getEvents($type);

        if (empty($events)) {
            return false;
        }

        $product_id    = (int) vRequest::getInt('virtuemart_product_id', 0);
        $productModel  = VmModel::getModel('product');
        $view->product = $productModel->getProduct($product_id);
        $view->user    = Factory::getUser();

        foreach ($events as $key => &$event) {
            if (!empty($event->language) && $event->language != '*' && !empty(VmConfig::$vmlangTag)) {
                if (VmConfig::$vmlangTag != $event->language) {
                    continue;
                }
            }

            if (!empty($event->filter_vendor)) {
                $vendor_id = !empty($view->product->virtuemart_vendor_id) ? $view->product->virtuemart_vendor_id : 1;

                if ((in_array($vendor_id, $event->filter_vendor) && !$event->filter_vendor_operator) || (!in_array($vendor_id, $event->filter_vendor) && $event->filter_vendor_operator)) {
                    unset($events[$key]);

                    continue;
                }
            }

            if (!empty($event->filter_product) || !empty($event->filter_category) || !empty($event->filter_manufacturer)) {
                $category_ids     = (array)$view->product->categories;
                $manufacturer_ids = (array) $view->product->virtuemart_manufacturer_id;
                $category_ids     = array_filter(array_map('intval', $category_ids));
                $manufacturer_ids = array_filter(array_map('intval', $manufacturer_ids));

                if (!empty($event->filter_product)) {
                    $event->filter_product = array_map('intval', $event->filter_product);
                    $matched = in_array($view->product->virtuemart_product_id, $event->filter_product);

                    if ((!empty($matched) && !$event->filter_product_operator) || (empty($matched) && $event->filter_product_operator)) {
                        unset($events[$key]);

                        continue;
                    }
                }

                if (!empty($event->filter_category)) {
                    $event->filter_category = array_map('intval', $event->filter_category);
                    $matched = array_intersect($event->filter_category, $category_ids);

                    if ((!empty($matched) && !$event->filter_category_operator) || (empty($matched) && $event->filter_category_operator)) {
                        unset($events[$key]);

                        continue;
                    }
                }

                if (!empty($event->filter_manufacturer)) {
                    $event->filter_manufacturer = array_map('intval', $event->filter_manufacturer);
                    $matched = array_intersect($event->filter_manufacturer, $manufacturer_ids);

                    if ((!empty($matched) && !$event->filter_manufacturer_operator) || (empty($matched) && $event->filter_manufacturer_operator)) {
                        unset($events[$key]);

                        continue;
                    }
                }
            }

            if ($event->filter_guests_only) {
                if ($view->user->id > 0) {
                    unset($events[$key]);

                    continue;
                }
            } elseif (!empty($event->filter_user)) {
                $user_id = $view->user->id;

                if ((in_array($user_id, $event->filter_user) && !$event->filter_user_operator) || (!in_array($user_id, $event->filter_user) && $event->filter_user_operator)) {
                    unset($events[$key]);

                    continue;
                }
            }

            if (!self::renderProductRecommendEmail($view, $event, false)) {
                return false;
            }
        }

        return $events;
    }

    public static function renderProductRecommendEmail($view, &$email, $isPreview = false)
    {
        $productModel = VmModel::getModel('product');

        // Load site language.
        self::loadLanguage();

        if (is_numeric($view)) {
            $product_id    = (int) $view;
            $view          = new stdClass();
            $view->product = $productModel->getProduct($product_id);
        }

        $view->user = Factory::getUser();
        $view->comment = vRequest::getString('comment');

        if ($isPreview) {
            $view->comment = 'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.';
        }

        $productModel->addImages($view->product);

        $friend_email = vRequest::getEmail('email', '');
        $friend_name  = vRequest::getVar('name', '');
        $friend_name  = str_replace(['\'', '"', ',', '%', '*', '/', '\\', '?', '^', '`', '{', '}', '|', '~'], [''], $friend_name);

        if ($isPreview) {
            $params          = JComponentHelper::getParams('com_vpem');
            $preview_user_id = (array) $params->get('preview_user_id', []);

            if (!empty($preview_user_id)) {
                $preview_user_id = array_filter(array_map('intval', $preview_user_id));
                $friend          = Factory::getUser($preview_user_id[0]);

                $friend_email = $friend->email;
                $friend_name  = $friend->name;
            }
        }

        $viewData = [
            'product' => $view->product,
            'user'    => [
                'email'    => $view->user->email,
                'name'     => $view->user->name
            ],
            'friend'  => [
                'email'    => $friend_email,
                'name'     => $friend_name
            ],
            'comment' => $view->comment
        ];

        $renderer = VpemHelperRenderer::getInstance();
        $mustache = $renderer->getMustache();

        $data = new VpemHelperProductdata($viewData, $mustache);

        if (!$renderer->renderMail($data, $email->subject, $email->body, $mustache)) {
            // TODO: Log error

            return false;
        }

        if ($isPreview) {
            $email->preview_subject = $email->subject;
        }

        $email->body = self::renderBody($email);

        return $email;
    }


    public static function renderProductQuestionEmails($view, $type = 'admin_ask_a_question')
    {
        $events = self::getEvents($type);

        if (empty($events)) {
            return false;
        }

        $product_id    = (int) vRequest::getInt('virtuemart_product_id', 0);
        $productModel  = VmModel::getModel('product');
        $view->product = $productModel->getProduct($product_id);
        $view->user    = Factory::getUser();

        foreach ($events as $key => &$event) {
            if (!empty($event->language) && $event->language != '*' && !empty(VmConfig::$vmlangTag)) {
                if (VmConfig::$vmlangTag != $event->language) {
                    continue;
                }
            }

            if (!empty($event->filter_vendor)) {
                $vendor_id = !empty($view->product->virtuemart_vendor_id) ? $view->product->virtuemart_vendor_id : 1;

                if ((in_array($vendor_id, $event->filter_vendor) && !$event->filter_vendor_operator) || (!in_array($vendor_id, $event->filter_vendor) && $event->filter_vendor_operator)) {
                    unset($events[$key]);

                    continue;
                }
            }

            if (!empty($event->filter_product) || !empty($event->filter_category) || !empty($event->filter_manufacturer)) {
                $category_ids     = (array)$view->product->categories;
                $manufacturer_ids = (array) $view->product->virtuemart_manufacturer_id;
                $category_ids     = array_filter(array_map('intval', $category_ids));
                $manufacturer_ids = array_filter(array_map('intval', $manufacturer_ids));

                if (!empty($event->filter_product)) {
                    $event->filter_product = array_map('intval', $event->filter_product);
                    $matched = in_array($view->product->virtuemart_product_id, $event->filter_product);

                    if ((!empty($matched) && !$event->filter_product_operator) || (empty($matched) && $event->filter_product_operator)) {
                        unset($events[$key]);

                        continue;
                    }
                }

                if (!empty($event->filter_category)) {
                    $event->filter_category = array_map('intval', $event->filter_category);
                    $matched = array_intersect($event->filter_category, $category_ids);

                    if ((!empty($matched) && !$event->filter_category_operator) || (empty($matched) && $event->filter_category_operator)) {
                        unset($events[$key]);

                        continue;
                    }
                }

                if (!empty($event->filter_manufacturer)) {
                    $event->filter_manufacturer = array_map('intval', $event->filter_manufacturer);
                    $matched = array_intersect($event->filter_manufacturer, $manufacturer_ids);

                    if ((!empty($matched) && !$event->filter_manufacturer_operator) || (empty($matched) && $event->filter_manufacturer_operator)) {
                        unset($events[$key]);

                        continue;
                    }
                }
            }

            if ($event->filter_guests_only) {
                if ($view->user->id > 0) {
                    unset($events[$key]);

                    continue;
                }
            } elseif (!empty($event->filter_user)) {
                $user_id = $view->user->id;

                if ((in_array($user_id, $event->filter_user) && !$event->filter_user_operator) || (!in_array($user_id, $event->filter_user) && $event->filter_user_operator)) {
                    unset($events[$key]);

                    continue;
                }
            }

            if (!self::renderProductQuestionEmail($view, $event, false)) {
                return false;
            }
        }

        return $events;
    }

    public static function renderProductQuestionEmail($view, &$email, $isPreview = false)
    {
        $productModel = VmModel::getModel('product');

        // Load site language.
        self::loadLanguage();

        if (is_numeric($view)) {
            $product_id    = (int) $view;
            $view          = new stdClass();
            $view->product = $productModel->getProduct($product_id);

            if ($isPreview) {
                $view->user = Factory::getUser();
            }
        }

        $view->comment = vRequest::getString('comment');

        if ($isPreview) {
            $view->comment = 'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.';
        }

        $productModel->addImages($view->product);

        if (!$isPreview) {
            $view->user = Factory::getUser();

            if (empty($view->user->id)) {
                $fromMail = vRequest::getEmail('email');
                $fromName = vRequest::getVar('name', '');
                $fromName = str_replace(array('\'', '"', ',', '%', '*', '/', '\\', '?', '^', '`', '{', '}', '|', '~'), array(''), $fromName);

                $view->user->email = $fromMail;
                $view->user->name = $fromName;
            }
        }

        $viewData = [
            'product' => $view->product,
            'user'    => [
                'email'    => $view->user->email,
                'name'     => $view->user->name
            ],
            'comment' => $view->comment
        ];

        $renderer = VpemHelperRenderer::getInstance();
        $mustache = $renderer->getMustache();

        $data = new VpemHelperProductdata($viewData, $mustache);

        if (!$renderer->renderMail($data, $email->subject, $email->body, $mustache)) {
            // TODO: Log error

            return false;
        }

        if ($isPreview) {
            $email->preview_subject = $email->subject;
        }

        $email->body = self::renderBody($email);

        return $email;
    }


    public static function renderUserEmails($view, $type)
    {
        $events = self::getEvents($type);

        if (empty($events)) {
            return false;
        }

        $userFieldsModel = VmModel::getModel('User');
        $userinfoTable   = $userFieldsModel->getTable('userinfos');
        $userinfo_id     = $userFieldsModel->getBTuserinfo_id($view->user->id);
        $userInfo        = $userinfoTable->load($userinfo_id);

        // Get valid events after applying filters
        foreach ($events as $key => $event) {
            if (!empty($event->language) && $event->language != '*' && !empty(VmConfig::$vmlangTag)) {
                if (VmConfig::$vmlangTag != $event->language) {
                    continue;
                }
            }

            if (!empty($event->filter_country) && isset($userInfo->virtuemart_country_id)) {
                if ((in_array($userInfo->virtuemart_country_id, $event->filter_country) && !$event->filter_country_operator) || (!in_array($userInfo->virtuemart_country_id, $event->filter_country) && $event->filter_country_operator)) {
                    unset($events[$key]);

                    continue;
                }
            }
        }

        if (empty($events)) {
            return false;
        }

        // Is Admin mail
        $isAdmin = strpos($type, 'admin') !== false;

        foreach ($events as &$event) {
            if (!self::renderUserEmail($view, $event, $isAdmin, false, $userInfo)) {
                return false;
            }
        }

        return $events;
    }

    public static function renderUserEmail($view, &$email, $isAdmin = false, $isPreview = false, $userInfo = null)
    {
        // Load site language.
        self::loadLanguage();

        // In case of preview pass only the user id
        if (is_numeric($view)) {
            $user_id              = (int) $view;
            $view                 = new stdClass();
            $view->user           = Factory::getUser($user_id);
            $view->password       = null;
            $view->activationLink = null;

            if ($isPreview) {
                $userParams = JComponentHelper::getParams('com_users');

                if ($userParams->get('sendpassword')) {
                    $view->password = '*******';
                }

                if ($userParams->get('useractivation')) {
                    $view->activationLink = '#';
                }
            }
        }

        if (empty($userInfo)) {
            $userFieldsModel = VmModel::getModel('User');
            $userinfoTable   = $userFieldsModel->getTable('userinfos');
            $userinfo_id     = $userFieldsModel->getBTuserinfo_id($view->user->id);
            $userInfo        = $userinfoTable->load($userinfo_id);
        }

        $userFieldsModel  = VmModel::getModel('UserFields');
        $userFields       = $userFieldsModel->getUserFields();
        $userFields       = $userFieldsModel->getUserFieldsFilled($userFields, $userInfo);
        $userData         = [
            'user'       => [],
            'userFields' => []
        ];
        $userData['user'] = [
            'username'       => $view->user->username,
            'email'          => $view->user->email,
            'name'           => $view->user->name,
            'password'       => $view->password,
            'activationLink' => null,
        ];

        if (!empty($view->activationLink)) {
            $userData['user']['activationLink'] = $view->activationLink;
        }

        foreach ($userFields['fields'] as $field) {
            if ($field['type'] == 'delimiter' || $field['type'] == 'hidden') {
                continue;
            }

            $name = $field['name'];

            if (!isset($userData['user'][$name])) {
                $userData['user'][$name] = $field['value'];

                $userData['userFields'][] = [
                    'name'  => $field['name'],
                    'title' => $field['title'],
                    'value' => $field['value']
                ];
            } else {
                $userData['userFields'][] = [
                    'name'  => $field['name'],
                    'title' => $field['title'],
                    'value' => $userData['user'][$name]
                ];
            }
        }

        if (isset($userData['user']['virtuemart_country_id'])) {
            $userData['user']['virtuemart_country_name'] = $userData['user']['virtuemart_country_id'];
        }

        if (isset($userData['user']['virtuemart_state_id'])) {
            $userData['user']['virtuemart_state_name'] = $userData['user']['virtuemart_state_id'];
        }

        $userData['isAdmin'] = $isAdmin;

        $renderer = VpemHelperRenderer::getInstance();
        $mustache = $renderer->getMustache();

        $data = new VpemHelperMustache($userData, $mustache);
        $data->setVendor();

        if (!$renderer->renderMail($data, $email->subject, $email->body, $mustache)) {
            // TODO: Log error

            return false;
        }

        if ($isPreview) {
            $email->preview_subject = $email->subject;
        }

        $email->body = self::renderBody($email);

        return $email;
    }


    public static function renderOrderEmails($order_id, $type, $eventId = null)
    {
        $events = self::getEvents($type);

        if (empty($events)) {
            return false;
        }

        $model        = VmModel::getModel('orders');
        $orderDetails = $model->getOrder($order_id);
        $isAdmin      = strpos($type, 'admin') !== false;

        if (empty($orderDetails)) {
            // TODO: Invalid order. Log error.

            return false;
        }

        // Get valid events after applying filters
        foreach ($events as $key => $event) {
            if (!empty($eventId) && $eventId != $event->id) {
                unset($events[$key]);

                continue;
            }

            if (!empty($event->filter_vendor)) {
                $vendor_id = $orderDetails['details']['BT']->virtuemart_vendor_id;

                if ((in_array($vendor_id, $event->filter_vendor) && !$event->filter_vendor_operator) || (!in_array($vendor_id, $event->filter_vendor) && $event->filter_vendor_operator)) {
                    unset($events[$key]);

                    continue;
                }
            }

            if (!empty($event->filter_product) || !empty($event->filter_category) || !empty($event->filter_manufacturer)) {
                $product_ids = [];
                $category_ids = [];
                $manufacturer_ids = [];

                foreach ($orderDetails['items'] as $item) {
                    $product_ids[]                    = $item->virtuemart_product_id;
                    $item->categories                 = (array) $item->categories;
                    $category_ids                     = array_merge($category_ids, $item->categories);
                    $item->virtuemart_manufacturer_id = (array) $item->virtuemart_manufacturer_id;
                    $manufacturer_ids                 = array_merge($manufacturer_ids, $item->virtuemart_manufacturer_id);
                }

                $product_ids      = array_filter(array_map('intval', $product_ids));
                $category_ids     = array_filter(array_map('intval', $category_ids));
                $manufacturer_ids = array_filter(array_map('intval', $manufacturer_ids));

                if (!empty($event->filter_product)) {
                    $event->filter_product = array_map('intval', $event->filter_product);
                    $matched = array_intersect($event->filter_product, $product_ids);

                    if ((!empty($matched) && !$event->filter_product_operator) || (empty($matched) && $event->filter_product_operator)) {
                        unset($events[$key]);

                        continue;
                    }
                }

                if (!empty($event->filter_category)) {
                    $event->filter_category = array_map('intval', $event->filter_category);
                    $matched = array_intersect($event->filter_category, $category_ids);

                    if ((!empty($matched) && !$event->filter_category_operator) || (empty($matched) && $event->filter_category_operator)) {
                        unset($events[$key]);

                        continue;
                    }
                }

                if (!empty($event->filter_manufacturer)) {
                    $event->filter_manufacturer = array_map('intval', $event->filter_manufacturer);
                    $matched = array_intersect($event->filter_manufacturer, $manufacturer_ids);

                    if ((!empty($matched) && !$event->filter_manufacturer_operator) || (empty($matched) && $event->filter_manufacturer_operator)) {
                        unset($events[$key]);

                        continue;
                    }
                }
            }

            if ($event->filter_guests_only) {
                if ($orderDetails['details']['BT']->virtuemart_user_id > 0) {
                    unset($events[$key]);

                    continue;
                }
            } elseif (!empty($event->filter_user)) {
                $user_id = $orderDetails['details']['BT']->virtuemart_user_id;

                if ((in_array($user_id, $event->filter_user) && !$event->filter_user_operator) || (!in_array($user_id, $event->filter_user) && $event->filter_user_operator)) {
                    unset($events[$key]);

                    continue;
                }
            }

            if (!empty($event->filter_shopper_group)) {
                $shopper_groups = $orderDetails['details']['BT']->user_shoppergroups;
                $shopper_groups = !is_array($shopper_groups) ? explode(',', $shopper_groups) : $shopper_groups;
                $shopper_groups = array_map('intval', $shopper_groups);
                $event->filter_shopper_group = array_map('intval', $event->filter_shopper_group);
                $matched = array_intersect($event->filter_shopper_group, $shopper_groups);

                if ((!empty($matched) && !$event->filter_shopper_group_operator) || (empty($matched) && $event->filter_shopper_group_operator)) {
                    unset($events[$key]);

                    continue;
                }
            }

            if (!empty($event->filter_country) && isset($orderDetails['details']['BT']->virtuemart_country_id)) {
                if ((in_array($orderDetails['details']['BT']->virtuemart_country_id, $event->filter_country) && !$event->filter_country_operator) || (!in_array($orderDetails['details']['BT']->virtuemart_country_id, $event->filter_country) && $event->filter_country_operator)) {
                    unset($events[$key]);

                    continue;
                }
            }

            if (!empty($event->filter_st_country) && isset($orderDetails['details']['ST']->virtuemart_country_id)) {
                if ((in_array($orderDetails['details']['ST']->virtuemart_country_id, $event->filter_st_country) && !$event->filter_st_country_operator) || (!in_array($orderDetails['details']['ST']->virtuemart_country_id, $event->filter_st_country) && $event->filter_st_country_operator)) {
                    unset($events[$key]);

                    continue;
                }
            }

            if (!empty($event->filter_shipment_method)) {
                if ((in_array($orderDetails['details']['BT']->virtuemart_shipmentmethod_id, $event->filter_shipment_method) && !$event->filter_shipment_method_operator) || (!in_array($orderDetails['details']['ST']->virtuemart_shipmentmethod_id, $event->filter_shipment_method) && $event->filter_shipment_method_operator)) {
                    unset($events[$key]);

                    continue;
                }
            }

            if (!empty($event->filter_payment_method)) {
                if ((in_array($orderDetails['details']['BT']->virtuemart_paymentmethod_id, $event->filter_payment_method) && !$event->filter_payment_method_operator) || (!in_array($orderDetails['details']['ST']->virtuemart_paymentmethod_id, $event->filter_payment_method) && $event->filter_payment_method_operator)) {
                    unset($events[$key]);

                    continue;
                }
            }

            if ($type !== 'order_followup' && !empty($event->filter_status)) {
                $order_status = $orderDetails['details']['BT']->order_status;

                if ((in_array($order_status, $event->filter_status) && !$event->filter_status_operator) || (!in_array($order_status, $event->filter_status) && $event->filter_status_operator)) {
                    unset($events[$key]);

                    continue;
                }
            }
        }

        if (empty($events)) {
            return false;
        }

        foreach ($events as &$event) {
            if (!self::renderOrderEmail($orderDetails, $event, $isAdmin)) {
                return false;
            }
        }

        return $events;
    }

    public static function renderOrderEmail($orderDetails, &$email, $isAdmin = false, $isPreview = false)
    {
        $model = VmModel::getModel('orders');

        if (is_numeric($orderDetails)) {
            $orderDetails = $model->getOrder($orderDetails);
        }

        // Load default shop language.
        self::loadOrderLanguages(VmConfig::$jDefLangTag);

        // Load language of VP Email Manager.
        self::loadLanguage();
        self::loadLanguage(VmConfig::$jDefLangTag);

        if (!$isAdmin && VmConfig::get('invoiceInUserLang', false) && !empty($orderDetails['details']['BT']->order_language)) {
            if (!empty($email->language) && $email->language != '*') {
                if ($orderDetails['details']['BT']->order_language != $email->language) {
                    return false;
                }
            }

            if ($orderDetails['details']['BT']->order_language != VmConfig::$vmlangTag) {
                // Load the user selected language for the order.
                self::loadOrderLanguages($orderDetails['details']['BT']->order_language);
                self::loadLanguage($orderDetails['details']['BT']->order_language);

                $orderDetails = $model->getOrder($orderDetails['details']['BT']->virtuemart_order_id);
            }
        } else {
            if (!empty($email->language) && $email->language != '*' && !empty(VmConfig::$vmlangTag)) {
                if (VmConfig::$vmlangTag != $email->language && VmConfig::$jDefLangTag != $email->language) {
                    return false;
                }
            }
        }

        //vpdump(vmLanguage::$currLangTag);exit;

        $order = new VpemHelperOrder($orderDetails);
        $order->process();

        $order->isAdmin = $isAdmin;

        $renderer = VpemHelperRenderer::getInstance();
        $mustache = $renderer->getMustache();

        $data = new VpemHelperOrderdata($order, $mustache, $order);

        if (!$renderer->renderMail($data, $email->subject, $email->body, $mustache)) {
            // TODO: Log error

            return false;
        }

        if ($isPreview) {
            $email->preview_subject = $email->subject;
        }

        $email->body = self::renderBody($email);

        return $email;
    }

    public static function renderBody($item)
    {
        JLoader::register('cssparser', JPATH_ADMINISTRATOR . '/components/com_vpem/libraries/cssparser/cssparser.php');

        $background_color = null;

        if (!empty($item->css_style)) {
            $css = new cssparser();
            $cssIndex = $css->ParseStr($item->css_style);

            $background_color = $css->Get('body', 'background-color');
        }

        $background_color = empty($background_color) ? '#FFFFFF' : $background_color;
        $displayData = ['background_color' => $background_color, 'item' => $item];

        return JLayoutHelper::render('compiled_mail', $displayData, null, ['client' => 'admin', 'component' => 'com_vpem']);
    }

    protected static function getEvents($type)
    {
        static $events = [];

        if (!isset($events[$type])) {
            $db    = Factory::getDbo();
            $query = $db->getQuery(true);

            $query->select('e.*')
                ->from($db->quoteName('#__vpem_events') . ' AS ' . $db->quoteName('e'))
                ->select($db->quoteName(['t.subject', 't.body', 't.css_style']))
                ->join('INNER', $db->quoteName('#__vpem_templates') . ' AS ' . $db->quoteName('t') . ' ON ' . $db->quoteName('t.id') . ' = ' . $db->quoteName('e.template_id'))
                ->where($db->quoteName('e.type') . ' = ' . $db->quote($type))
                ->where($db->quoteName('e.state') . ' = 1')
                ->where($db->quoteName('t.state') . ' = 1');

            $db->setQuery($query);
            $events[$type] = $db->loadObjectList();

            $multiple_fields = ['attachments', 'filter_vendor', 'filter_product', 'filter_category', 'filter_manufacturer', 'filter_user', 'filter_shopper_group', 'filter_country', 'filter_st_country', 'filter_shipment_method', 'filter_payment_method', 'filter_status'];

            foreach ($events[$type] as &$item) {
                foreach ($multiple_fields as $multiple_field) {
                    if (!empty($item->$multiple_field) && is_string($item->$multiple_field)) {
                        $registry = new Registry($item->$multiple_field);

                        $item->$multiple_field = $registry->toArray();
                    }
                }
            }
        }

        $list = [];

        if (is_array($events[$type])) {
            foreach ($events[$type] as $event) {
                $list[] = clone $event;
            }
        }

        return $list;
    }

    /**
     * Gets the files attached to an item
     *
     * @param   int     $pk     The item's id
     *
     * @param   string  $table  The table's name
     *
     * @param   string  $field  The field's name
     *
     * @return  array  The files
     */
    public static function getFiles($pk, $table, $field)
    {
        $db = Factory::getDbo();
        $query = $db->getQuery(true);

        $query
            ->select($field)
            ->from($table)
            ->where('id = ' . (int) $pk);

        $db->setQuery($query);

        return explode(',', $db->loadResult());
    }

    /**
     * Gets a list of the actions that can be performed.
     *
     * @return    JObject
     */
    public static function getActions()
    {
        $user   = Factory::getUser();
        $result = new JObject();

        $assetName = 'com_vpem';

        $actions = [
            'core.admin', 'core.manage', 'core.create', 'core.edit', 'core.edit.own', 'core.edit.state', 'core.delete'
        ];

        foreach ($actions as $action) {
            $result->set($action, $user->authorise($action, $assetName));
        }

        return $result;
    }

    public static function displayMailAddresses($addresses)
    {
        if (empty($addresses)) {
            return '';
        }

        $addresses = explode(',', $addresses);

        foreach ($addresses as &$address) {
            $address = '&#60;' . $address . '&#62';
        }

        return implode('; ', $addresses);
    }

    public static function loadLanguage($langTag = null, $reload = true)
    {
        $reInjectJLanguage = null;
        $params            = JComponentHelper::getParams('com_vpem');

        if ($params->get('force_load_language', 1) && JLanguageMultilang::isEnabled()) {
            $reInjectJLanguage = VmConfig::get('ReInjectJLanguage', false);

            VmConfig::set('ReInjectJLanguage', true);

            if (class_exists('vmLanguage') && method_exists('vmLanguage', 'setLanguageByTag')) {
                vmLanguage::setLanguageByTag($langTag);
            }
        }

        Factory::getLanguage()->load('com_vpem', JPATH_SITE, $langTag, $reload);

        if ($reInjectJLanguage !== null) {
            VmConfig::set('ReInjectJLanguage', $reInjectJLanguage);
        }
    }

    public static function loadOrderLanguages($langTag = null, $reload = true)
    {
        $lang              = Factory::getLanguage();
        $params            = JComponentHelper::getParams('com_vpem');
        $reInjectJLanguage = null;

        if ($params->get('force_load_language', 1) && JLanguageMultilang::isEnabled()) {
            $reInjectJLanguage = VmConfig::get('ReInjectJLanguage', false);

            VmConfig::set('ReInjectJLanguage', true);
        }

        shopFunctionsF::loadOrderLanguages($langTag);

        $lang->load('com_virtuemart', JPATH_ADMINISTRATOR, $langTag, $reload);
        $lang->load('com_virtuemart', JPATH_SITE, $langTag, $reload);
        $lang->load('com_virtuemart_shoppers', JPATH_SITE, $langTag, $reload);
        $lang->load('com_virtuemart_orders', JPATH_SITE, $langTag, $reload);

        if ($reInjectJLanguage !== null) {
            VmConfig::set('ReInjectJLanguage', $reInjectJLanguage);
        }
    }
}
