<?php

/**
 * @package    VP Email Manager
 * @copyright  Copyright (C) 2012-2024 VirtuePlanet Services LLP. All rights reserved.
 * @license    GNU General Public License version 3 or later; see LICENSE.txt
 * @author     Abhishek Das <info@virtueplanet.com>
 * @link       https://www.virtueplanet.com
 *
 * @phpcs:disable PSR1.Classes.ClassDeclaration.MissingNamespace
 */

use Joomla\CMS\Factory;

// phpcs:disable PSR1.Files.SideEffects
defined('_JEXEC') or die;

JLoader::register('VmConfig', JPATH_ADMINISTRATOR . '/components/com_virtuemart/helpers/config.php');
JLoader::register('ShopFunctions', JPATH_ADMINISTRATOR . '/components/com_virtuemart/helpers/shopfunctions.php');
JLoader::register('TableCategories', JPATH_ADMINISTRATOR . '/components/com_virtuemart/tables/categories.php');
JLoader::register('VmModel', JPATH_ADMINISTRATOR . '/components/com_virtuemart/helpers/vmmodel.php');
// phpcs:enable PSR1.Files.SideEffects

class JFormFieldVMCategories extends JFormField
{
    public $type = 'VMCategories';

    protected function getInput()
    {
        VmConfig::loadConfig();
        VmConfig::loadJLang('com_virtuemart');

        if (is_string($this->value) && !empty($this->value)) {
            $this->value = explode(',', $this->value);
        }

        $attr = '';

        if (!$this->multiple) {
            $this->class = $this->class ? $this->class . ' form-select' : 'form-select';
        }

        // Initialize some field attributes.
        $attr .= !empty($this->class) ? ' class="' . $this->class . '"' : '';
        $attr .= !empty($this->size) ? ' size="' . $this->size . '"' : '';
        $attr .= $this->multiple ? ' multiple' : '';
        $attr .= $this->required ? ' required aria-required="true"' : '';
        $attr .= $this->autofocus ? ' autofocus' : '';

        // To avoid user's confusion, readonly="true" should imply disabled="true".
        if ((string) $this->readonly == '1' || (string) $this->readonly == 'true' || (string) $this->disabled == '1' || (string) $this->disabled == 'true') {
            $attr .= ' disabled="disabled"';
        }

        // Initialize JavaScript field attributes.
        $attr .= $this->onchange ? ' onchange="' . $this->onchange . '"' : '';

        $categorylist = ShopFunctions::categoryListTree($this->value);

        if (version_compare(JVERSION, '4.0.0', 'ge') && $this->multiple) {
            /** @var Joomla\CMS\Application\AdministratorApplication $app */
            $app = Factory::getApplication();
            $app->getDocument()->getWebAssetManager()
                ->usePreset('choicesjs')
                ->useScript('webcomponent.field-fancy-select');

            $html  = '<joomla-field-fancy-select  placeholder="Type or select some options">';
            $html .= '<select id="' . $this->id . '" name="' . $this->name . '" ' . trim($attr) . '>';
            $html .= $categorylist;
            $html .= '</select>';
            $html .= '</joomla-field-fancy-select>';
        } else {
            $html  = '<select id="' . $this->id . '" name="' . $this->name . '" ' . trim($attr) . '>';
            $html .= $categorylist;
            $html .= '</select>';
        }

        return $html;
    }
}
