<?php

/**
 * @package    VP Email Manager
 * @copyright  Copyright (C) 2012-2024 VirtuePlanet Services LLP. All rights reserved.
 * @license    GNU General Public License version 3 or later; see LICENSE.txt
 * @author     Abhishek Das <info@virtueplanet.com>
 * @link       https://www.virtueplanet.com
 *
 * @phpcs:disable PSR1.Classes.ClassDeclaration.MissingNamespace
 */

use Joomla\CMS\Factory;

// phpcs:disable PSR1.Files.SideEffects
defined('_JEXEC') or die;

JFormHelper::loadFieldClass('newlist');
// phpcs:enable PSR1.Files.SideEffects

class JFormFieldVMCountries extends JFormFieldNewlist
{
    public $type = 'VMCountries';

    protected static $countries = null;

    protected function getOptions()
    {
        if (self::$countries === null) {
            $db    = Factory::getDBO();
            $query = $db->getQuery(true)
                ->select('c.virtuemart_country_id AS id, c.country_name AS name, c.country_3_code')
                ->from('#__virtuemart_countries AS c')
                ->where('c.published = 1')
                ->order('c.country_name ASC');

            try {
                $db->setQuery($query);
                self::$countries = $db->loadObjectList();
            } catch (Exception $e) {
                Factory::getApplication()->enqueueMessage($e->getMessage(), 'error');
                return false;
            }
        }

        $lang = Factory::getLanguage();

        $lang->load('com_virtuemart_countries', JPATH_ADMINISTRATOR);
        $lang->load('com_virtuemart_countries', JPATH_ADMINISTRATOR . '/components/com_virtuemart');

        $options = array();

        foreach (self::$countries as $country) {
            $key = 'COM_VIRTUEMART_COUNTRY_' . strtoupper($country->country_3_code);
            $text = $lang->hasKey($key) ? JText::_($key) : $country->name;

            $options[] = JHtml::_('select.option', (int) $country->id, $text);
        }

        return array_merge(parent::getOptions(), $options);
    }
}
