<?php

/**
 * @package    VP Email Manager
 * @copyright  Copyright (C) 2012-2024 VirtuePlanet Services LLP. All rights reserved.
 * @license    GNU General Public License version 3 or later; see LICENSE.txt
 * @author     Abhishek Das <info@virtueplanet.com>
 * @link       https://www.virtueplanet.com
 *
 * @phpcs:disable PSR1.Classes.ClassDeclaration.MissingNamespace
 */

// phpcs:disable PSR1.Files.SideEffects
defined('_JEXEC') or die;

JFormHelper::loadFieldClass('newlist');
// phpcs:enable PSR1.Files.SideEffects

class JFormFieldVMPayments extends JFormFieldNewlist
{
    public $type = 'vmpayments';

    protected static $payments = null;

    protected function getOptions()
    {
        JLoader::register('VmConfig', JPATH_ROOT . '/administrator/components/com_virtuemart/helpers/config.php');

        VmConfig::loadConfig();
        VmConfig::loadJLang('com_virtuemart');

        if (version_compare(JVERSION, '4.0.0', 'ge') && $this->multiple) {
            $this->layout = 'joomla.form.field.list-fancy-select';
        }

        if (self::$payments === null) {
            $db    = JFactory::getDbo();
            $query = $db->getQuery(true)
                ->select('a.virtuemart_paymentmethod_id AS value, b.payment_name AS text')
                ->from($db->quoteName('#__virtuemart_paymentmethods') . ' AS a')
                ->join('INNER', $db->quoteName('#__virtuemart_paymentmethods_' . VmConfig::$vmlang) . ' AS b ON b.virtuemart_paymentmethod_id = a.virtuemart_paymentmethod_id')
                ->where($db->quoteName('a.published') . ' = 1');

            $db->setQuery($query);

            try {
                $payments = $db->loadObjectList();
            } catch (Exception $e) {
                JFactory::getApplication()->enqueueMessage($e->getMessage(), 'error');

                return false;
            }

            self::$payments = $payments;
        }

        $options = array();

        if (!empty(self::$payments)) {
            foreach (self::$payments as $payment) {
                $options[] = JHTML::_('select.option', (int) $payment->value, htmlspecialchars($payment->text, ENT_COMPAT, 'UTF-8', false));
            }
        }

        return array_merge(parent::getOptions(), $options);
    }
}
