<?php

/**
 * @package    VP Email Manager
 * @copyright  Copyright (C) 2012-2024 VirtuePlanet Services LLP. All rights reserved.
 * @license    GNU General Public License version 3 or later; see LICENSE.txt
 * @author     Abhishek Das <info@virtueplanet.com>
 * @link       https://www.virtueplanet.com
 *
 * @phpcs:disable PSR1.Classes.ClassDeclaration.MissingNamespace
 */

// phpcs:disable PSR1.Files.SideEffects
defined('_JEXEC') or die;

JFormHelper::loadFieldClass('newlist');
// phpcs:enable PSR1.Files.SideEffects

class JFormFieldVMShipments extends JFormFieldNewlist
{
    public $type = 'vmshipments';

    protected static $shipments = null;

    protected function getOptions()
    {
        JLoader::register('VmConfig', JPATH_ROOT . '/administrator/components/com_virtuemart/helpers/config.php');

        VmConfig::loadConfig();
        VmConfig::loadJLang('com_virtuemart');

        if (self::$shipments === null) {
            $db    = JFactory::getDbo();
            $query = $db->getQuery(true)
                ->select('a.virtuemart_shipmentmethod_id AS value, b.shipment_name AS text')
                ->from($db->quoteName('#__virtuemart_shipmentmethods') . ' AS a')
                ->join('INNER', $db->quoteName('#__virtuemart_shipmentmethods_' . VmConfig::$vmlang) . ' AS b ON b.virtuemart_shipmentmethod_id = a.virtuemart_shipmentmethod_id')
                ->where($db->quoteName('a.published') . ' = 1');

            $db->setQuery($query);

            try {
                $shipments = $db->loadObjectList();
            } catch (Exception $e) {
                JFactory::getApplication()->enqueueMessage($e->getMessage(), 'error');
                return false;
            }

            self::$shipments = $shipments;
        }

        $options = array();

        if (!empty(self::$shipments)) {
            foreach (self::$shipments as $shipment) {
                $options[] = JHTML::_('select.option', (int) $shipment->value, htmlspecialchars($shipment->text, ENT_COMPAT, 'UTF-8', false));
            }
        }

        return array_merge(parent::getOptions(), $options);
    }
}
