<?php

/**
 * @package    VP Email Manager
 * @copyright  Copyright (C) 2012-2024 VirtuePlanet Services LLP. All rights reserved.
 * @license    GNU General Public License version 3 or later; see LICENSE.txt
 * @author     Abhishek Das <info@virtueplanet.com>
 * @link       https://www.virtueplanet.com
 *
 * @phpcs:disable PSR1.Classes.ClassDeclaration.MissingNamespace
 */

use Joomla\CMS\Factory;
use Joomla\CMS\HTML\HTMLHelper;

// phpcs:disable PSR1.Files.SideEffects
defined('_JEXEC') or die;

JFormHelper::loadFieldClass('newlist');
// phpcs:enable PSR1.Files.SideEffects

class JFormFieldVMStatuses extends JFormFieldNewlist
{
    public $type = 'VMStatuses';

    protected static $statuses = null;

    protected function getInput()
    {
        if (!empty($this->value) && is_string($this->value) && $this->multiple) {
            $this->value = explode(',', $this->value);
        }

        return parent::getInput();
    }

    protected function getOptions()
    {
        JLoader::register('VmConfig', JPATH_ADMINISTRATOR . '/components/com_virtuemart/helpers/config.php');

        VmConfig::loadConfig();
        VmConfig::loadJLang('com_virtuemart');
        VmConfig::loadJLang('com_virtuemart_orders', true);

        $options = array();

        if (self::$statuses === null) {
            $db    = Factory::getDBO();
            $query = $db->getQuery(true);

            $query->select($db->quoteName('os.order_status_code') . ' AS value')
                ->select($db->quoteName('os.order_status_name') . ' AS text')
                ->from($db->quoteName('#__virtuemart_orderstates') . ' AS os')
                //->where($db->quoteName('os.published') . ' = 1')
                ->order($db->quoteName('os.virtuemart_orderstate_id') . ' ASC');

            try {
                $db->setQuery($query);
                self::$statuses = $db->loadObjectList();
            } catch (Exception $e) {
                Factory::getApplication()->enqueueMessage($e->getMessage(), 'error');
                return false;
            }
        }

        foreach (self::$statuses as $status) {
            $options[] = HTMLHelper::_('select.option', $status->value, JText::_($status->text));
        }

        return array_merge(parent::getOptions(), $options);
    }
}
