<?php

/**
 * @package    VP Email Manager
 * @copyright  Copyright (C) 2012-2024 VirtuePlanet Services LLP. All rights reserved.
 * @license    GNU General Public License version 3 or later; see LICENSE.txt
 * @author     Abhishek Das <info@virtueplanet.com>
 * @link       https://www.virtueplanet.com
 *
 * @phpcs:disable PSR1.Classes.ClassDeclaration.MissingNamespace
 */

use Joomla\CMS\Factory;

// phpcs:disable PSR1.Files.SideEffects
defined('_JEXEC') or die;

JFormHelper::loadFieldClass('list');
// phpcs:enable PSR1.Files.SideEffects

class JFormFieldVpemtemplate extends JFormFieldList
{
    public $type = 'vpemtemplate';

    protected static $templates = null;

    protected function getOptions()
    {
        if (self::$templates === null) {
            $db    = JFactory::getDBO();
            $query = $db->getQuery(true);

            $query->select($db->quoteName(['id', 'name', 'type', 'state']))
                ->from($db->quoteName('#__vpem_templates'))
                ->where($db->quoteName('state') . ' IN(0, 1)')
                ->order($db->quoteName('name') . ' ASC');

            try {
                $db->setQuery($query);
                self::$templates = $db->loadObjectList();
            } catch (Exception $e) {
                Factory::getApplication()->enqueueMessage($e->getMessage(), 'error');
                return false;
            }
        }

        $type = $this->form->getField('type') && $this->form->getField('type')->value ? $this->form->getField('type')->value : '';

        if (is_array($type) && isset($type[0])) {
            $type = $type[0];
        }

        $options = [];

        foreach (self::$templates as $template) {
            if ($template->type == $type) {
                $options[] = JHtml::_('select.option', (int) $template->id, $template->name, 'value', 'text', empty($template->state));
            }
        }

        return array_merge(parent::getOptions(), $options);
    }
}
