<?php
/**
 * @package    VP Email Manager
 * @copyright  Copyright (C) 2012-2024 VirtuePlanet Services LLP. All rights reserved.
 * @license    GNU General Public License version 3 or later; see LICENSE.txt
 * @author     Abhishek Das <info@virtueplanet.com>
 * @link       https://www.virtueplanet.com
 */

defined('_JEXEC') or die;

use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Factory;
use Joomla\CMS\Uri\Uri;
use Joomla\CMS\Router\Route;
use Joomla\CMS\Language\Text;

HTMLHelper::addIncludePath(JPATH_COMPONENT . '/helpers/html');

HTMLHelper::_('jquery.framework');

if (version_compare(JVERSION, '4.0.0', 'ge'))
{
	$wa = $this->document->getWebAssetManager();
	$wa->useScript('keepalive')
		->useScript('form.validate');
}
else
{
	HTMLHelper::_('behavior.tooltip');
	HTMLHelper::_('behavior.formvalidation');
	HTMLHelper::_('formbehavior.chosen', 'select');
	HTMLHelper::_('behavior.keepalive');
}

HTMLHelper::_('script', 'com_vpem/app.js', ['relative' => true, 'version' => '2.0']);
HTMLHelper::_('stylesheet', 'com_vpem/style.css', ['relative' => true, 'version' => '2.0']);

$document = Factory::getDocument();

if (!version_compare(JVERSION, '4.0.0', 'ge'))
{
	$document->addScriptDeclaration("
		Joomla.submitbutton = function (task) {
			if (task == 'event.cancel' || task == 'event.settype') {
				Joomla.submitform(task, document.getElementById('event-form'));
			} else {
				if (task != 'event.cancel' && document.formvalidator.isValid(document.getElementById('event-form'))) {
					Joomla.submitform(task, document.getElementById('event-form'));
				} else {
					alert('" . $this->escape(Text::_('JGLOBAL_VALIDATION_FORM_FAILED')) . "');
				}
			}
		}
	");
}

$document->addStyleDeclaration("
	.spacer label {
		font-weight: bold;
	}
");

$tabPrefix       = version_compare(JVERSION, '4.0.0', 'ge') ? 'uitab' : 'bootstrap';
$formClassSuffix = version_compare(JVERSION, '4.0.0', 'ge') ? 'joomla-4' : 'joomla-3';
?>
<form action="<?php echo JRoute::_('index.php?option=com_vpem&view=event&layout=edit&id=' . (int) $this->item->id); ?>" method="post" name="adminForm" id="event-form" class="form-validate <?php echo $formClassSuffix; ?>" data-id="<?php echo (int) $this->item->id; ?>">
	
	<?php if (version_compare(JVERSION, '4.0.0', 'ge')) : ?>
		<div class="row title-alias form-vertical mb-3">
			<?php if (!empty($this->type)) : ?>
				<div class="col-12 col-md-6">
					<div class="control-group">
						<div class="control-label">
							<?php echo $this->form->getLabel('name'); ?>
						</div>
						<div class="controls">
							<?php echo $this->form->getInput('name'); ?>
							<?php if (!$this->form->getField('name')->value) : ?>
								<div class="field-hint small muted"><?php echo JText::_('COM_VPEM_FORM_HINT_TEMPLATE_NAME'); ?></div>
							<?php endif; ?>
						</div>
					</div>
				</div>
			<?php endif; ?>
			<div class="col-12 col-md-6">
				<div class="control-group">
					<div class="control-label">
						<?php echo $this->form->getLabel('type'); ?>
					</div>
					<div class="controls">
						<?php echo $this->form->getInput('type'); ?>
						<?php if (!$this->form->getField('type')->value) : ?>
							<div class="field-hint small muted text-error"><?php echo JText::_('COM_VPEM_FORM_HINT_TYPE_NAME'); ?></div>
						<?php endif; ?>
					</div>
				</div>
			</div>
		</div>
	<?php else : ?>
		<div class="form-inline form-inline-header">
			<?php if (!empty($this->type)) : ?>
				<div class="control-group">
					<div class="control-label">
						<?php echo $this->form->getLabel('name'); ?>
					</div>
					<div class="controls">
						<?php echo $this->form->getInput('name'); ?>
						<?php if (!$this->form->getField('name')->value) : ?>
							<div class="field-hint small muted"><?php echo JText::_('COM_VPEM_FORM_HINT_TEMPLATE_NAME'); ?></div>
						<?php endif; ?>
					</div>
				</div>
			<?php endif; ?>
			<div class="control-group">
				<div class="control-label">
					<?php echo $this->form->getLabel('type'); ?>
				</div>
				<div class="controls">
					<?php echo $this->form->getInput('type'); ?>
					<?php if (!$this->form->getField('type')->value) : ?>
						<div class="field-hint small muted text-error"><?php echo JText::_('COM_VPEM_FORM_HINT_TYPE_NAME'); ?></div>
					<?php endif; ?>
				</div>
			</div>
		</div>
	<?php endif; ?>
	
	<?php if (!empty($this->type)) : ?>
		
		<div class="main-card">
	
			<?php echo HTMLHelper::_($tabPrefix . '.startTabSet', 'myTab', array('active' => 'event', 'recall' => true, 'breakpoint' => 768)); ?>
			
				<?php echo HTMLHelper::_($tabPrefix . '.addTab', 'myTab', 'event', Text::_('COM_VPEM_TAB_EVENT')); ?>
					<div class="<?php echo version_compare(JVERSION, '4.0.0', 'ge') ? 'row' : 'row-fluid'; ?>">
						<div class="<?php echo version_compare(JVERSION, '4.0.0', 'ge') ? 'col-12 col-md-9' : 'span9'; ?> form-horizontal pt-2">
							<?php echo $this->form->renderField('template_id'); ?>
							<?php echo $this->form->renderField('mail_to'); ?>
							<?php echo $this->form->renderField('mail_cc'); ?>
							<?php echo $this->form->renderField('mail_bcc'); ?>
							<?php echo $this->form->renderField('attachments'); ?>
							<hr/>
							<?php echo $this->form->renderField('mail_from'); ?>
							<?php echo $this->form->renderField('mail_from_name'); ?>
							<hr/>
							<?php echo $this->form->renderField('reply_to'); ?>
							<?php echo $this->form->renderField('reply_to_name'); ?>
							<hr/>
							<?php echo $this->form->renderField('order_followup'); ?>
							<?php echo $this->form->renderField('followup_starts_on'); ?>
							<?php echo $this->form->renderField('interval_uom'); ?>
							<?php echo $this->form->renderField('minutes'); ?>
							<?php echo $this->form->renderField('hours'); ?>
							<?php echo $this->form->renderField('days'); ?>
							<?php echo $this->form->renderField('weeks'); ?>
							<?php echo $this->form->renderField('months'); ?>
							<?php echo $this->form->renderField('years'); ?>
							
							<?php if ($this->type === 'order_followup') : ?>
								<?php echo $this->form->renderField('filter_status'); ?>
							<?php endif; ?>
							
							<?php echo $this->form->renderField('conditions'); ?>
							<?php echo $this->form->renderField('filter_vendor'); ?>
							<?php echo $this->form->renderField('filter_vendor_operator'); ?>
							<?php echo $this->form->renderField('filter_product'); ?>
							<?php echo $this->form->renderField('filter_product_operator'); ?>
							<?php echo $this->form->renderField('filter_category'); ?>
							<?php echo $this->form->renderField('filter_category_operator'); ?>
							<?php echo $this->form->renderField('filter_manufacturer'); ?>
							<?php echo $this->form->renderField('filter_manufacturer_operator'); ?>
							<?php echo $this->form->renderField('filter_guests_only'); ?>
							<?php echo $this->form->renderField('filter_user'); ?>
							<?php echo $this->form->renderField('filter_user_operator'); ?>
							<?php echo $this->form->renderField('filter_shopper_group'); ?>
							<?php echo $this->form->renderField('filter_shopper_group_operator'); ?>
							<?php echo $this->form->renderField('filter_country'); ?>
							<?php echo $this->form->renderField('filter_country_operator'); ?>
							<?php echo $this->form->renderField('filter_st_country'); ?>
							<?php echo $this->form->renderField('filter_st_country_operator'); ?>
							<?php echo $this->form->renderField('filter_shipment_method'); ?>
							<?php echo $this->form->renderField('filter_shipment_method_operator'); ?>
							<?php echo $this->form->renderField('filter_payment_method'); ?>
							<?php echo $this->form->renderField('filter_payment_method_operator'); ?>
							
							<?php if ($this->type !== 'order_followup') : ?>
								<?php echo $this->form->renderField('filter_status'); ?>
							<?php endif; ?>
							
							<?php echo $this->form->renderField('filter_status_operator'); ?>
						</div>
						<div class="<?php echo version_compare(JVERSION, '4.0.0', 'ge') ? 'col-12 col-md-3' : 'span3'; ?> form-vertical">
							<?php echo $this->form->renderField('state'); ?>
							<?php echo $this->form->renderField('language'); ?>
							<?php echo $this->form->renderField('created_by'); ?>
							<?php echo $this->form->renderField('created_on'); ?>
							<?php echo $this->form->renderField('modified_by'); ?>
							<?php echo $this->form->renderField('modified_on'); ?>
							<?php if ($this->state->params->get('save_history', 1)) : ?>
								<div class="control-group">
									<div class="control-label"><?php echo $this->form->getLabel('version_note'); ?></div>
									<div class="controls"><?php echo $this->form->getInput('version_note'); ?></div>
								</div>
								<?php echo $this->form->renderField('id'); ?>
							<?php endif; ?>
						</div>
					</div>
				<?php echo HTMLHelper::_($tabPrefix . '.endTab'); ?>
			
			<?php echo HTMLHelper::_($tabPrefix . '.endTabSet'); ?>
		
		</div>
	<?php endif; ?>

	<?php echo $this->form->getInput('checked_out'); ?>
	<?php echo $this->form->getInput('checked_out_time'); ?>
	<input type="hidden" name="task" value=""/>
	<?php echo HTMLHelper::_('form.token'); ?>
</form>
