<?php
/**
 * @package    VP Email Manager
 * @copyright  Copyright (C) 2012-2024 VirtuePlanet Services LLP. All rights reserved.
 * @license    GNU General Public License version 3 or later; see LICENSE.txt
 * @author     Abhishek Das <info@virtueplanet.com>
 * @link       https://www.virtueplanet.com
 */

defined('_JEXEC') or die;

jimport('joomla.application.component.view');

use \Joomla\CMS\Factory;
use \Joomla\CMS\Language\Text;

/**
 * View to edit
 */
class VpemViewEvent extends \Joomla\CMS\MVC\View\HtmlView
{
	protected $state;

	protected $item;

	protected $form;
	
	protected $type;

	/**
	 * Display the view
	 *
	 * @param   string  $tpl  Event name
	 *
	 * @return void
	 *
	 * @throws Exception
	 */
	public function display($tpl = null)
	{
		$this->state = $this->get('State');
		$this->item  = $this->get('Item');
		$this->form  = $this->get('Form');
		
		$type = $this->form->getField('type') && $this->form->getField('type')->value ? $this->form->getField('type')->value : $this->item->type;
		$this->type = is_array($type) && isset($type[0]) ? $type[0] : $type;
		
		// Check for errors.
		if (count($errors = $this->get('Errors')))
		{
			throw new Exception(implode("\n", $errors));
		}

		$this->addToolbar();
		parent::display($tpl);
	}

	/**
	 * Add the page title and toolbar.
	 *
	 * @return void
	 *
	 * @throws Exception
	 */
	protected function addToolbar()
	{
		Factory::getApplication()->input->set('hidemainmenu', true);

		$user  = Factory::getUser();
		$isNew = ($this->item->id == 0);
		$canDo = VpemHelper::getActions();
		
		if (isset($this->item->checked_out))
		{
			$checkedOut = !($this->item->checked_out == 0 || $this->item->checked_out == $user->get('id'));
		}
		else
		{
			$checkedOut = false;
		}
		
		if ($isNew)
		{
			JToolBarHelper::title(Text::_('COM_VPEM') . ': ' . Text::_('COM_VPEM_TITLE_EVENTS') . ': ' . Text::_('COM_VPEM_ADD_EVENT'), 'lamp event.png');
		}
		else
		{
			JToolBarHelper::title(Text::_('COM_VPEM') . ': ' . Text::_('COM_VPEM_TITLE_EVENTS') . ': ' . Text::_('COM_VPEM_EDIT_EVENT'), 'lamp event.png');
		}

		// If not checked out, can save the item.
		if (!$checkedOut && ($canDo->get('core.edit') || ($canDo->get('core.create'))))
		{
			JToolBarHelper::apply('event.apply', 'JTOOLBAR_APPLY');
			JToolBarHelper::save('event.save', 'JTOOLBAR_SAVE');
		}

		if (!$checkedOut && ($canDo->get('core.create')))
		{
			JToolBarHelper::custom('event.save2new', 'save-new.png', 'save-new_f2.png', 'JTOOLBAR_SAVE_AND_NEW', false);
		}

		// If an existing item, can save to a copy.
		if (!$isNew && $canDo->get('core.create'))
		{
			JToolBarHelper::custom('event.save2copy', 'save-copy.png', 'save-copy_f2.png', 'JTOOLBAR_SAVE_AS_COPY', false);
		}

		// Button for version control
		if ($this->state->params->get('save_history', 1) && $user->authorise('core.edit'))
		{
			// JToolbarHelper::versions('com_vpem.event', $this->item->id);
		}

		if (empty($this->item->id))
		{
			JToolBarHelper::cancel('event.cancel', 'JTOOLBAR_CANCEL');
		}
		else
		{
			JToolBarHelper::cancel('event.cancel', 'JTOOLBAR_CLOSE');
		}
		
		if (version_compare(JVERSION, '4.0.0', 'ge'))
		{
			// JToolbarHelper::divider();
			// JToolbarHelper::inlinehelp();
		}
	}
}
