<?php
/**
 * @package    VP Email Manager
 * @copyright  Copyright (C) 2012-2024 VirtuePlanet Services LLP. All rights reserved.
 * @license    GNU General Public License version 3 or later; see LICENSE.txt
 * @author     Abhishek Das <info@virtueplanet.com>
 * @link       https://www.virtueplanet.com
 */

defined('_JEXEC') or die;

use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Factory;
use Joomla\CMS\Uri\Uri;
use Joomla\CMS\Router\Route;
use Joomla\CMS\Layout\LayoutHelper;
use Joomla\CMS\Language\Text;

HTMLHelper::addIncludePath(JPATH_COMPONENT . '/helpers/');

HTMLHelper::_('jquery.framework');

if (!version_compare(JVERSION, '4.0.0', 'ge'))
{
	HTMLHelper::_('bootstrap.tooltip');
	HTMLHelper::_('behavior.multiselect');
	HTMLHelper::_('formbehavior.chosen', 'select');
}

HTMLHelper::_('script', 'com_vpem/app.js', ['relative' => true, 'version' => '2.0']);
HTMLHelper::_('stylesheet', 'com_vpem/style.css', ['relative' => true, 'version' => '2.0']);

$document  = Factory::getDocument();
$user      = Factory::getUser();
$userId    = $user->get('id');
$listOrder = $this->state->get('list.ordering');
$listDirn  = $this->state->get('list.direction');
?>
<form action="<?php echo Route::_('index.php?option=com_vpem&view=events'); ?>" method="post" name="adminForm" id="adminForm">
	<?php if (!empty($this->sidebar) && !version_compare(JVERSION, '4.0.0', 'ge')): ?>
	<div id="j-sidebar-container" class="span2">
		<?php echo $this->sidebar; ?>
	</div>
	<div id="j-main-container" class="span10">
		<?php else : ?>
		<div id="j-main-container">
			<?php endif; ?>
			<?php echo LayoutHelper::render('joomla.searchtools.default', ['view' => $this]); ?>
			<div class="clearfix"></div>
			<table class="table table-striped" id="templateList">
				<thead>
				<tr>
					<th width="1%" class="hidden-phone d-none d-sm-table-cell">
						<input type="checkbox" name="checkall-toggle" value="" title="<?php echo Text::_('JGLOBAL_CHECK_ALL'); ?>" onclick="Joomla.checkAll(this)"/>
					</th>
					<th width="1%" class="nowrap center">
						<?php echo HTMLHelper::_('searchtools.sort', 'JSTATUS', 'a.state', $listDirn, $listOrder); ?>
					</th>
					<th width="1%" class="center hidden-phone d-none d-sm-table-cell">
						<?php echo HTMLHelper::_('searchtools.sort', 'COM_VPEM_EVENT_TEMPLATE_STATUS', 't.state', $listDirn, $listOrder); ?>
					</th>
					<th class="left">
						<?php echo HTMLHelper::_('searchtools.sort', 'COM_VPEM_EVENT_NAME', 'a.name', $listDirn, $listOrder); ?>
					</th>
					<th class="left hidden-phone d-none d-sm-table-cell">
						<?php echo HTMLHelper::_('searchtools.sort', 'COM_VPEM_EVENT_TEMPLATE_NAME', 't.name', $listDirn, $listOrder); ?>
					</th>
					<th class="left">
						<?php echo HTMLHelper::_('searchtools.sort', 'COM_VPEM_TEMPLATES_TYPE', 'a.type', $listDirn, $listOrder); ?>
					</th>
					<th class="left hidden-phone d-none d-sm-table-cell">
						<?php echo HTMLHelper::_('searchtools.sort', 'JGRID_HEADING_LANGUAGE', 'a.language', $listDirn, $listOrder); ?>
					</th>
					<th class="left hidden-phone d-none d-sm-table-cell">
						<?php echo HTMLHelper::_('searchtools.sort', 'COM_VPEM_TEMPLATES_CREATED_BY', 'a.created_by', $listDirn, $listOrder); ?>
					</th>
					<th class="left hidden-phone d-none d-sm-table-cell">
						<?php echo HTMLHelper::_('searchtools.sort', 'COM_VPEM_TEMPLATES_CREATED_ON', 'a.created_on', $listDirn, $listOrder); ?>
					</th>
					<th width="1%" class="left hidden-phone d-none d-sm-table-cell">
						<?php echo HTMLHelper::_('searchtools.sort', 'COM_VPEM_TEMPLATES_ID', 'a.id', $listDirn, $listOrder); ?>
					</th>
				</tr>
				</thead>
				<tfoot>
				<tr>
					<td colspan="<?php echo isset($this->items[0]) ? count(get_object_vars($this->items[0])) : 10; ?>">
						<?php echo $this->pagination->getListFooter(); ?>
					</td>
				</tr>
				</tfoot>
				<tbody>
				<?php foreach ($this->items as $i => $item) :
					$ordering   = ($listOrder == 'a.ordering');
					$canCreate  = $user->authorise('core.create', 'com_vpem');
					$canEdit    = $user->authorise('core.edit', 'com_vpem');
					$canCheckin = $user->authorise('core.manage', 'com_vpem');
					$canChange  = $user->authorise('core.edit.state', 'com_vpem');
					?>
					<tr class="row<?php echo $i % 2; ?>">
						<td class="hidden-phone d-none d-sm-table-cell">
							<?php echo HTMLHelper::_('grid.id', $i, $item->id); ?>
						</td>
						<td class="center">
							<?php echo HTMLHelper::_('jgrid.published', $item->state, $i, 'events.', $canChange, 'cb'); ?>
						</td>
						<td class="center hidden-phone d-none d-sm-table-cell">
							<?php echo HTMLHelper::_('jgrid.published', $item->template_state, $i, 'templates.', false, 'cb'); ?>
						</td>
						<td>
							<?php if (isset($item->checked_out) && $item->checked_out && ($canEdit || $canChange)) : ?>
								<?php echo HTMLHelper::_('jgrid.checkedout', $i, $item->uEditor, $item->checked_out_time, 'events.', $canCheckin); ?>
							<?php endif; ?>
							<?php if ($canEdit) : ?>
								<a href="<?php echo JRoute::_('index.php?option=com_vpem&task=event.edit&id='.(int) $item->id); ?>">
								<?php echo $this->escape($item->name); ?></a>
							<?php else : ?>
								<?php echo $this->escape($item->name); ?>
							<?php endif; ?>
						</td>
						<td class="hidden-phone d-none d-sm-table-cell">
							<?php if ($canEdit) : ?>
								<a href="<?php echo JRoute::_('index.php?option=com_vpem&task=template.edit&id='.(int) $item->template_id); ?>">
								<?php echo $this->escape($item->template_name); ?></a>
							<?php else : ?>
								<?php echo $this->escape($item->template_name); ?>
							<?php endif; ?>
						</td>
						<td>
							<?php echo $item->type; ?>
						</td>
						<td class="small hidden-phone d-none d-sm-table-cell">
							<?php echo JLayoutHelper::render('joomla.content.language', $item); ?>
						</td>
						<td class="small hidden-phone d-none d-sm-table-cell">
							<?php echo !empty($item->created_by) ? $item->created_by : '-'; ?>
						</td>
						<td class="small hidden-phone d-none d-sm-table-cell">
							<?php echo (int) $item->created_on > 0 ? HTMLHelper::_('date',  $item->created_on, JText::_('DATE_FORMAT_LC4')) : '-'; ?>
						</td>
						<td class="hidden-phone d-none d-sm-table-cell">
							<?php echo $item->id; ?>
						</td>
					</tr>
				<?php endforeach; ?>
				</tbody>
			</table>

			<input type="hidden" name="task" value=""/>
			<input type="hidden" name="boxchecked" value="0" />
			<input type="hidden" name="list[fullorder]" value="<?php echo $listOrder; ?> <?php echo $listDirn; ?>"/>
			<?php echo HTMLHelper::_('form.token'); ?>
		</div>
</form>
<script>
    window.toggleField = function (id, task, field) {

        var f = document.adminForm, i = 0, cbx, cb = f[ id ];

        if (!cb) return false;

        while (true) {
            cbx = f[ 'cb' + i ];

            if (!cbx) break;

            cbx.checked = false;
            i++;
        }

        var inputField   = document.createElement('input');

        inputField.type  = 'hidden';
        inputField.name  = 'field';
        inputField.value = field;
        f.appendChild(inputField);

        cb.checked = true;
        f.boxchecked.value = 1;
        window.submitform(task);

        return false;
    };
</script>