<?php
/**
 * @package    VP Email Manager
 * @copyright  Copyright (C) 2012-2024 VirtuePlanet Services LLP. All rights reserved.
 * @license    GNU General Public License version 3 or later; see LICENSE.txt
 * @author     Abhishek Das <info@virtueplanet.com>
 * @link       https://www.virtueplanet.com
 */

defined('_JEXEC') or die;

use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Factory;
use Joomla\CMS\Uri\Uri;
use Joomla\CMS\Router\Route;
use Joomla\CMS\Language\Text;

HTMLHelper::addIncludePath(JPATH_COMPONENT . '/helpers/html');

HTMLHelper::_('jquery.framework');

if (version_compare(JVERSION, '4.0.0', 'ge'))
{
	$wa = $this->document->getWebAssetManager();
	$wa->useScript('keepalive')
		->useScript('form.validate');
}
else
{
	HTMLHelper::_('behavior.tooltip');
	HTMLHelper::_('behavior.formvalidation');
	HTMLHelper::_('formbehavior.chosen', 'select');
	HTMLHelper::_('behavior.keepalive');
}

HTMLHelper::_('script', 'com_vpem/app.js', ['relative' => true, 'version' => '2.0']);
HTMLHelper::_('stylesheet', 'com_vpem/style.css', ['relative' => true, 'version' => '2.0']);

$document = Factory::getDocument();

$document->addStyleDeclaration("
	.vpem-mail-header {
		border-bottom: 1px solid #ddd;
		padding-bottom: 10px;
	}
	.attachment {
		display: inline-block;
		margin-right: 10px;
	}
");

$document->addScriptDeclaration("
	jQuery(document).ready(function($) {
		var html = $('#vpem-real-body').html();
		var iframe = document.getElementById('vpem-iframe');
		var doc = iframe.contentWindow.document;
		doc.open();
		doc.write(html);
		doc.close();
		
		$(iframe.contentWindow.document).find('a').each(function() {
			if (!$(this).attr('target')) {
				$(this).attr('target', '_blank');
			}
		});
		
		iframe.style.height = iframe.contentWindow.document.documentElement.scrollHeight + 'px';
		
		setTimeout(function() {
			iframe.style.height = iframe.contentWindow.document.documentElement.scrollHeight + 'px';
		}, 1000);
		
		$('[data-attachment]').off('click').on('click', function(e) {
			e.preventDefault();
			var filename = $(this).data('file');
			
			if (filename) {
				var form = $('#attachment-form');
				form.find('input[name=\"file\"]').val(filename);
				form.submit();
			}
			
			return false;
		});
	});
");
?>
<?php if (!empty($this->sidebar) && !version_compare(JVERSION, '4.0.0', 'ge')): ?>
<div id="j-sidebar-container" class="span2">
	<?php echo $this->sidebar; ?>
</div>
<div id="j-main-container" class="span10">
<?php else : ?>
<div id="j-main-container">
<?php endif; ?>
	<div class="vpem-mail">
		<div class="vpem-mail-header">
			<?php if (empty($this->item->status) && !empty($this->item->error_message)) : ?>
				<div class="alert alert-error alert-block">
					<?php echo $this->item->error_message; ?>
				</div>
			<?php endif; ?>
			<table width="100%" border="0" cellpadding="2">
				<tbody>
					<tr>
						<td width="1%" class="nowrap"><strong><?php echo JText::_('COM_VPEM_MAIL_FROM'); ?>:</strong></td>
						<td><?php echo $this->item->from_name; ?> <?php echo VpemHelper::displayMailAddresses($this->item->mail_from); ?></td>
					</tr>
					<?php if (!empty($this->item->reply_to)) : ?>
						<tr>
							<td width="1%" class="nowrap"><strong><?php echo JText::_('COM_VPEM_MAIL_REPLY_TO'); ?>:</strong></td>
							<td><?php echo $this->item->reply_to_name; ?> <?php echo VpemHelper::displayMailAddresses($this->item->reply_to); ?></td>
						</tr>
					<?php endif; ?>
					<tr>
						<td width="1%" class="nowrap"><strong><?php echo JText::_('COM_VPEM_MAIL_TO'); ?>:</strong></td>
						<td><?php echo !empty($this->item->mail_to) ? VpemHelper::displayMailAddresses($this->item->mail_to) : ''; ?></td>
					</tr>
					<?php if (!empty($this->item->cc)) : ?>
						<tr>
							<td width="1%" class="nowrap"><strong><?php echo JText::_('COM_VPEM_MAIL_CC'); ?>:</strong></td>
							<td><?php echo VpemHelper::displayMailAddresses($this->item->cc); ?></td>
						</tr>
					<?php endif; ?>
					<?php if (!empty($this->item->bcc)) : ?>
						<tr>
							<td width="1%" class="nowrap"><strong><?php echo JText::_('COM_VPEM_MAIL_BCC'); ?>:</strong></td>
							<td><?php echo VpemHelper::displayMailAddresses($this->item->bcc); ?></td>
						</tr>
					<?php endif; ?>
					<tr>
						<td width="1%" class="nowrap"><strong><?php echo JText::_('COM_VPEM_MAIL_SUBJECT'); ?>:</strong></td>
						<td><?php echo $this->item->subject; ?></td>
					</tr>
					<tr>
						<td width="1%" class="nowrap"><strong><?php echo JText::_('COM_VPEM_MAIL_SENT_ON'); ?>:</strong></td>
						<td><?php echo $this->item->sent_on > 0 ? JHtml::_('date', $this->item->sent_on, JText::_('DATE_FORMAT_LC5')) : '-'; ?></td>
					</tr>
					<?php if (!empty($this->item->attachments)) : ?>
						<tr>
							<td width="1%" class="nowrap"><strong><?php echo JText::_('COM_VPEM_MAIL_ATTACHMENTS'); ?>:</strong></td>
							<td>
								<?php foreach ($this->item->attachments as $file) : ?>
									<span class="attachment">
										<a href="#" data-file="<?php echo base64_encode($file); ?>" data-attachment title="<?php echo $this->escape($file); ?>"><?php echo $this->escape(basename($file)); ?></a>
									</span>
								<?php endforeach; ?>
							</td>
						</tr>
					<?php endif; ?>
				</tbody>
			</table>
		</div>
		<div class="vpem-mail-body">
			<iframe id="vpem-iframe" src="about:blank" width="100%" height="100%" frameborder="0" style="border: 0 none; width: 100%;"></iframe>
		</div>
		<script id="vpem-real-body" type="text/template">
			<?php echo $this->item->body; ?>
		</script>
		<form accept="<?php echo JRoute::_('index.php?option=com_vpem&task=mail.download'); ?>" method="post" id="attachment-form">
			<input type="hidden" name="file" value="" />
			<input type="hidden" name="option" value="com_vpem" />
			<input type="hidden" name="task" value="mail.download" />
			<?php echo JHtml::_('form.token'); ?>
		</form>
	</div>
</div>