<?php
/**
 * @package    VP Email Manager
 * @copyright  Copyright (C) 2012-2024 VirtuePlanet Services LLP. All rights reserved.
 * @license    GNU General Public License version 3 or later; see LICENSE.txt
 * @author     Abhishek Das <info@virtueplanet.com>
 * @link       https://www.virtueplanet.com
 */

defined('_JEXEC') or die;

jimport('joomla.application.component.view');

use Joomla\CMS\Factory;
use Joomla\CMS\Language\Text;

/**
 * View to edit
 */
class VpemViewTemplate extends \Joomla\CMS\MVC\View\HtmlView
{
	protected $state;

	protected $item;

	protected $form;
	
	protected $type;
	
	protected $variables;

	/**
	 * Display the view
	 *
	 * @param   string  $tpl  Template name
	 *
	 * @return void
	 *
	 * @throws Exception
	 */
	public function display($tpl = null)
	{
		$this->state     = $this->get('State');
		$this->item      = $this->get('Item');
		$this->form      = $this->get('Form');
		
		$type = $this->form->getField('type') && $this->form->getField('type')->value ? $this->form->getField('type')->value : $this->item->type;
		$type = is_array($type) && isset($type[0]) ? $type[0] : $type;

		if ($type && (strpos($type, 'order_') === 0 || strpos($type, 'admin_order_') === 0))
		{
			$this->variables = $this->get('OrderVariables');
		}
		elseif ($type && (strpos($type, 'user_') === 0 || strpos($type, 'admin_user_') === 0))
		{
			$this->variables = $this->get('UserVariables');
		}
		elseif ($type && $type == 'admin_ask_a_question')
		{
			$this->variables = $this->get('ProductVariables');
		}
		elseif ($type && $type == 'recommend_product')
		{
			$this->variables = $this->get('RecommendProductVariables');
		}
		elseif ($type && $type == 'product_notification')
		{
			$this->variables = $this->get('ProductNotifyVariables');
		}
		
		$this->type = $type;

		// Check for errors.
		if (count($errors = $this->get('Errors')))
		{
			throw new Exception(implode("\n", $errors));
		}

		$this->addToolbar();
		parent::display($tpl);
	}

	/**
	 * Add the page title and toolbar.
	 *
	 * @return void
	 *
	 * @throws Exception
	 */
	protected function addToolbar()
	{
		Factory::getApplication()->input->set('hidemainmenu', true);

		$user  = Factory::getUser();
		$isNew = ($this->item->id == 0);
		
		// Get the toolbar object instance
		$bar = JToolbar::getInstance('toolbar');

		if (isset($this->item->checked_out))
		{
			$checkedOut = !($this->item->checked_out == 0 || $this->item->checked_out == $user->get('id'));
		}
		else
		{
			$checkedOut = false;
		}

		$canDo = VpemHelper::getActions();
		
		if ($isNew)
		{
			JToolBarHelper::title(Text::_('COM_VPEM') . ': ' . Text::_('COM_VPEM_TITLE_TEMPLATES') . ': ' . Text::_('COM_VPEM_ADD_TEMPLATE'), 'eye template');
		}
		else
		{
			JToolBarHelper::title(Text::_('COM_VPEM') . ': ' . Text::_('COM_VPEM_TITLE_TEMPLATES') . ': ' . Text::_('COM_VPEM_EDIT_TEMPLATE'), 'eye template');
		}

		// If not checked out, can save the item.
		if (!$checkedOut && ($canDo->get('core.edit') || ($canDo->get('core.create'))))
		{
			JToolBarHelper::apply('template.apply', 'JTOOLBAR_APPLY');
			JToolBarHelper::save('template.save', 'JTOOLBAR_SAVE');
		}

		if (!$checkedOut && ($canDo->get('core.create')))
		{
			JToolBarHelper::custom('template.save2new', 'save-new.png', 'save-new_f2.png', 'JTOOLBAR_SAVE_AND_NEW', false);
		}

		// If an existing item, can save to a copy.
		if (!$isNew && $canDo->get('core.create'))
		{
			JToolBarHelper::custom('template.save2copy', 'save-copy.png', 'save-copy_f2.png', 'JTOOLBAR_SAVE_AS_COPY', false);
		}

		// Button for version control
		if ($this->state->params->get('save_history', 1) && $user->authorise('core.edit'))
		{
			// JToolbarHelper::versions('com_vpem.template', $this->item->id);
		}

		if (empty($this->item->id))
		{
			JToolBarHelper::cancel('template.cancel', 'JTOOLBAR_CANCEL');
		}
		else
		{
			JToolBarHelper::cancel('template.cancel', 'JTOOLBAR_CLOSE');
		}
		
		if (!empty($this->item->id))
		{
			if (version_compare(JVERSION, '4.0.0', 'ge'))
			{
				$url = 'index.php?option=com_vpem&task=template.getpreview&format=raw&id=' . (int) $this->item->id . '&' . JSession::getFormToken() . '=1';
				
				$bar->preview($url, 'COM_VPEM_TITLE_PREVIEW')
					->bodyHeight(80)
					->modalWidth(90);
			}
			else
			{
				// Instantiate a new JLayoutFile instance and render the batch button
				$layout = new JLayoutFile('joomla.toolbar.modal');

				$dhtml = $layout->render(array('text' => JText::_('COM_VPEM_TITLE_PREVIEW'), 'selector' => 'previewModal'));

				$bar->appendButton('Custom', $dhtml, 'batch');
			}
		}
	}
}
