<?php

/**
 * @package    VP Email Manager
 * @copyright  Copyright (C) 2012-2024 VirtuePlanet Services LLP. All rights reserved.
 * @license    GNU General Public License version 3 or later; see LICENSE.txt
 * @author     Abhishek Das <info@virtueplanet.com>
 * @link       https://www.virtueplanet.com
 *
 * @phpcs:disable PSR1.Classes.ClassDeclaration.MissingNamespace
 * @phpcs:disable Squiz.Classes.ValidClassName.NotCamelCaps
 */

// phpcs:disable PSR1.Files.SideEffects
defined('_JEXEC') or die;
// phpcs:enable PSR1.Files.SideEffects

class shopFunctionsF extends shopFunctionsFOriginal
{
    /**
     * Prepares a view for rendering email, then renders and sends
     *
     * @param object $controller
     * @param string $viewName View which will render the email
     * @param string $recipient shopper@whatever.com
     * @param array $vars variables to assign to the view
     */
    // TODO this is quirk, why it is using here $noVendorMail, but everywhere else it is using $doVendor => this make logic trouble
    public static function renderMail($viewName, $recipient, $vars = [], $controllerName = null, $noVendorMail = false, $useDefault = true)
    {
        self::loadOrderLanguages();

        /** @var object $view */
        $view = self::prepareViewForMail($viewName, $vars, $controllerName);
        $user = self::sendVmMail($view, $recipient, $noVendorMail);

        if (isset($view->doVendor) && !$noVendorMail) {
            // We need to ensure the language for the vendor here
            if (!empty($vars['virtuemart_vendor_id'])) {
                $vendorId = $vars['virtuemart_vendor_id'];
            } else {
                $vendorId = 1;
            }

            $vendorUserId = VmModel::getModel('vendor')->getUserIdByVendorId($vendorId);
            $vu           = JFactory::getUser($vendorUserId);
            $vLang        = $vu->getParam('admin_language', VmConfig::$jDefLangTag);

            vmLanguage::setLanguageByTag($vLang);

            self::sendVmMail($view, $view->vendorEmail, true);
        }

        return $user;
    }

    /**
     * With this function you can use a view to sent it by email.
     * Just use a task in a controller
     *
     * @param string $view for example user, cart
     * @param string $recipient shopper@whatever.com
     * @param bool $vendor true for notifying vendor of user action (e.g. registration)
     */
    public static function sendVmMail(&$view, $recipient, $noVendorMail = false, $processed = false)
    {
        if (!$processed) {
            return self::sendVpemMail($view, $recipient, $noVendorMail);
        }

        return parent::sendVmMail($view, $recipient, $noVendorMail);
    }

    /**
     * Try to send mails trough VP Email Manager
     *
     * @param undefined $view
     * @param undefined $recipient
     * @param undefined $noVendorMail
     *
     * @return mixed
     */
    protected static function sendVpemMail(&$view, $recipient, $noVendorMail = false)
    {
        JLoader::register('VpemHelper', JPATH_ADMINISTRATOR . '/components/com_vpem/helpers/vpem.php');

        $viewName = '';
        $mailSent = false;

        if (is_object($view)) {
            $viewClass = get_class($view);
            $viewClass = strtolower($viewClass);
            $viewName  = null;

            if (!empty($viewClass) && strpos($viewClass, 'virtuemartview') === 0) {
                $viewName = str_replace('virtuemartview', '', $viewClass);
            }

            if (!$viewName) {
                $parentViewClass = get_parent_class($viewClass);
                $parentViewClass = $parentViewClass ? strtolower($parentViewClass) : $parentViewClass;

                if (!empty($parentViewClass) && strpos($parentViewClass, 'virtuemartview') === 0) {
                    $viewName = str_replace('virtuemartview', '', $parentViewClass);
                }
            }

            $mailSent = VpemHelper::sendMail($viewName, $view, $recipient, $noVendorMail);
        }

        if (!$mailSent) {
            return self::sendVmMail($view, $recipient, $noVendorMail, true);
        }

        return $mailSent;
    }
}
