<?php

/**
 * @package    VP Email Manager
 * @copyright  Copyright (C) 2012-2024 VirtuePlanet Services LLP. All rights reserved.
 * @license    GNU General Public License version 3 or later; see LICENSE.txt
 * @author     Abhishek Das <info@virtueplanet.com>
 * @link       https://www.virtueplanet.com
 *
 * @phpcs:disable PSR1.Classes.ClassDeclaration.MissingNamespace
 * @phpcs:disable Squiz.Classes.ValidClassName.NotCamelCaps
 */

use Joomla\CMS\Factory;

// phpcs:disable PSR1.Files.SideEffects
defined('_JEXEC') or die;
// phpcs:enable PSR1.Files.SideEffects

/**
 * VP Email Manager Component Package Script
 *
 * @since   1.1
 */
class com_vpemInstallerScript
{
    protected static $tableColumns = [];

    /**
     * Called on installation
     *
     * @param   Joomla\CMS\Installer\Adapter\PackageAdapter  $adapter  The object responsible for running this script
     *
     * @return  boolean  True on success
     */
    public function install($adapter)
    {
        return true;
    }

    /**
     * Called on update
     *
     * @param   Joomla\CMS\Installer\Adapter\PackageAdapter  $adapter  The object responsible for running this script
     *
     * @return  boolean  True on success
     */
    public function update($adapter)
    {
        $db = Factory::getDbo();

        if ($this->isTableColumnUnsigned('#__vpem_events', 'state')) {
            $db->setQuery('ALTER TABLE ' . $db->quoteName('#__vpem_events') . ' MODIFY COLUMN ' . $db->quoteName('checked_out') . ' int(11) NOT NULL DEFAULT ' . $db->quote('0'));
            $db->execute();

            $this->setDefaultValueToVarcharColumns('#__vpem_events');
            $this->setDefaultValueToIntegerColumns('#__vpem_events');
        }

        if ($this->isTableColumnUnsigned('#__vpem_templates', 'state')) {
            $db->setQuery('ALTER TABLE ' . $db->quoteName('#__vpem_templates') . ' MODIFY COLUMN ' . $db->quoteName('state') . ' tinyint(1) NOT NULL DEFAULT ' . $db->quote('0'));
            $db->execute();

            $this->setDefaultValueToVarcharColumns('#__vpem_templates');
            $this->setDefaultValueToIntegerColumns('#__vpem_templates');
        }

        $this->setDefaultValueToVarcharColumns('#__vpem_outbox');
        $this->setDefaultValueToIntegerColumns('#__vpem_outbox');
        $this->createNewTables();

        return true;
    }

    /**
     * Called before any type of action
     *
     * @param     string                                         $route      Which action is happening (install|uninstall|discover_install)
     * @param     Joomla\CMS\Installer\Adapter\PackageAdapter    $adapter    The object responsible for running this script
     *
     * @return    boolean                         True on success
     */
    public function preflight($route, $adapter)
    {
        if ($route === 'update') {
            $db = Factory::getDbo();

            if (!$this->columnExists('#__vpem_events', 'attachments')) {
                $db->setQuery('ALTER TABLE ' . $db->quoteName('#__vpem_events') . ' ADD COLUMN ' . $db->quoteName('attachments') . ' text NOT NULL AFTER ' . $db->quoteName('mail_from_name'));
                $db->execute();
            }

            if (!$this->columnExists('#__vpem_events', 'interval_uom')) {
                $db->setQuery('ALTER TABLE ' . $db->quoteName('#__vpem_events') . ' ADD COLUMN ' . $db->quoteName('interval_uom') . ' VARCHAR(15) NOT NULL DEFAULT ' . $db->quote('') . ' AFTER ' . $db->quoteName('attachments'));
                $db->execute();
            }

            if (!$this->columnExists('#__vpem_events', 'intervals')) {
                $db->setQuery('ALTER TABLE ' . $db->quoteName('#__vpem_events') . ' ADD COLUMN ' . $db->quoteName('intervals') . ' VARCHAR(512) NOT NULL DEFAULT ' . $db->quote('') . ' AFTER ' . $db->quoteName('interval_uom'));
                $db->execute();
            }

            if (!$this->columnExists('#__vpem_events', 'followup_starts_on')) {
                $db->setQuery('ALTER TABLE ' . $db->quoteName('#__vpem_events') . ' ADD COLUMN ' . $db->quoteName('followup_starts_on') . ' DATETIME NOT NULL DEFAULT ' . $db->quote('0000-00-00 00:00:00') . ' AFTER ' . $db->quoteName('attachments'));
                $db->execute();
            }

            if (!$this->columnExists('#__vpem_events', 'filter_shipment_method')) {
                $db->setQuery('ALTER TABLE ' . $db->quoteName('#__vpem_events') . ' ADD COLUMN ' . $db->quoteName('filter_shipment_method') . ' text NOT NULL AFTER ' . $db->quoteName('filter_st_country_operator'));
                $db->execute();
            }

            if (!$this->columnExists('#__vpem_events', 'filter_shipment_method_operator')) {
                $db->setQuery('ALTER TABLE ' . $db->quoteName('#__vpem_events') . ' ADD COLUMN ' . $db->quoteName('filter_shipment_method_operator') . ' tinyint(1) NOT NULL DEFAULT ' . $db->quote('1') . ' AFTER ' . $db->quoteName('filter_shipment_method'));
                $db->execute();
            }

            if (!$this->columnExists('#__vpem_events', 'filter_payment_method')) {
                $db->setQuery('ALTER TABLE ' . $db->quoteName('#__vpem_events') . ' ADD COLUMN ' . $db->quoteName('filter_payment_method') . ' text NOT NULL AFTER ' . $db->quoteName('filter_shipment_method'));
                $db->execute();
            }

            if (!$this->columnExists('#__vpem_events', 'filter_payment_method_operator')) {
                $db->setQuery('ALTER TABLE ' . $db->quoteName('#__vpem_events') . ' ADD COLUMN ' . $db->quoteName('filter_payment_method_operator') . ' tinyint(1) NOT NULL DEFAULT ' . $db->quote('1') . ' AFTER ' . $db->quoteName('filter_payment_method'));
                $db->execute();
            }
        }

        return true;
    }


    /**
     * Called after any type of action
     *
     * @param     string                                         $route      Which action is happening (install|uninstall|discover_install)
     * @param     Joomla\CMS\Installer\Adapter\PackageAdapter    $adapter    The object responsible for running this script
     *
     * @return    boolean                         True on success
     */
    public function postflight($route, $adapter)
    {
        return true;
    }

    /**
     * Method to create the new tables added after updates.
     *
     * @return void
     */
    private function createNewTables()
    {
        $db = Factory::getDbo();

        // Create #__vpem_followups table.
        $query  = 'CREATE TABLE IF NOT EXISTS ' . $db->quoteName('#__vpem_followups') . ' ( ';
        $query .= $db->quoteName('id') . ' int(11) UNSIGNED NOT NULL AUTO_INCREMENT, ';
        $query .= $db->quoteName('event_id') . ' int(11) UNSIGNED NOT NULL DEFAULT ' . $db->quote('0') . ', ';
        $query .= $db->quoteName('order_id') . ' int(11) UNSIGNED NOT NULL DEFAULT ' . $db->quote('0') . ', ';
        $query .= $db->quoteName('status') . ' tinyint(1) NOT NULL DEFAULT ' . $db->quote('0') . ', ';
        $query .= $db->quoteName('sent_on') . ' datetime NOT NULL DEFAULT ' . $db->quote('0000-00-00 00:00:00') . ', ';
        $query .= 'PRIMARY KEY (' . $db->quoteName('id') . '), ';
        $query .= 'KEY ' . $db->quoteName('idx_event_id') . ' (' . $db->quoteName('event_id') . '), ';
        $query .= 'KEY ' . $db->quoteName('idx_order_id') . ' (' . $db->quoteName('order_id') . ')';
        $query .= ') ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci';

        $db->setQuery($query);
        $db->execute();

        // Create #__vpem_datetime table.
        $query  = 'CREATE TABLE IF NOT EXISTS ' . $db->quoteName('#__vpem_datetime') . ' ( ';
        $query .= $db->quoteName('id') . ' int(11) UNSIGNED NOT NULL AUTO_INCREMENT, ';
        $query .= $db->quoteName('type') . ' varchar(110) NOT NULL DEFAULT ' . $db->quote('') . ', ';
        $query .= $db->quoteName('time') . ' datetime NOT NULL DEFAULT ' . $db->quote('0000-00-00 00:00:00') . ', ';
        $query .= 'PRIMARY KEY (' . $db->quoteName('id') . ')';
        $query .= ') ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci';

        $db->setQuery($query);
        $db->execute();
    }

    /**
     * Method to set a default value to non-nullable varchar columns.
     *
     * @param   string  $table  The name of the table.
     *
     * @return void
     */
    private function setDefaultValueToVarcharColumns($table)
    {
        $db      = Factory::getDbo();
        $columns = $this->getTableColumns($table);

        foreach ($columns as $column => $data) {
            if (!property_exists($data, 'Type') || !property_exists($data, 'Default') || !property_exists($data, 'Null')) {
                continue;
            }

            if (stripos($data->Type, 'varchar') === 0 && $data->Null === 'NO' && $data->Default === null) {
                $db->setQuery('ALTER TABLE ' . $db->quoteName($table) . ' MODIFY COLUMN ' . $db->quoteName($column) . ' ' . $data->Type . ' NOT NULL DEFAULT ' . $db->quote(''));
                $db->execute();
            }
        }
    }

    /**
     * Method to set a default value to non-nullable int or tinyint columns.
     *
     * @param   string   $table         The name of the table.
     * @param   integer  $defaultValue  The default value.
     *
     * @return void
     */
    private function setDefaultValueToIntegerColumns($table, $defaultValue = 0)
    {
        $db      = Factory::getDbo();
        $columns = $this->getTableColumns($table);

        foreach ($columns as $column => $data) {
            if (!property_exists($data, 'Type') || !property_exists($data, 'Default') || !property_exists($data, 'Null')) {
                continue;
            }

            if ($column === 'id' && $data->Default == '0') {
                $query = $db->getQuery(true);

                $query->select('MAX(id)')
                    ->from($db->quoteName($table));

                $db->setQuery($query);
                $maxId = $db->loadResult();

                $db->setQuery('ALTER TABLE ' . $db->quoteName('#__vpem_outbox') . ' CHANGE COLUMN ' . $db->quoteName('id') . ' ' . $db->quoteName('id') . ' int(11) UNSIGNED NOT NULL AUTO_INCREMENT, AUTO_INCREMENT = ' . ($maxId + 1));
                $db->execute();
            } elseif ((stripos($data->Type, 'int') === 0 || stripos($data->Type, 'tinyint') === 0) && $data->Null === 'NO' && $data->Default === null && $column !== 'id') {
                $db->setQuery('ALTER TABLE ' . $db->quoteName($table) . ' MODIFY COLUMN ' . $db->quoteName($column) . ' ' . $data->Type . ' NOT NULL DEFAULT ' . $db->quote($defaultValue));
                $db->execute();
            }
        }
    }

    /**
     * Check if a column exists in a database table.
     *
     * @param    string    $table   The name of the table.
     * @param    string    $column  The name of the column.
     *
     * @return   boolean
     */
    private function columnExists($table, $column)
    {
        $columns     = $this->getTableColumns($table);
        $columnNames = array_keys($columns);

        return in_array($column, $columnNames);
    }

    /**
     * Check if a column has unsigned attribute in a database table.
     *
     * @param    string    $table   The name of the table.
     * @param    string    $column  The name of the column.
     *
     * @return
     */
    private function isTableColumnUnsigned($table, $column)
    {
        $columns = $this->getTableColumns($table);

        if (array_key_exists($column, $columns)) {
            $columnData = $columns[$column];

            if (property_exists($columnData, 'Type') && stripos($columnData->Type, 'unsigned') === false) {
                return false;
            }
        }

        return true;
    }

    /**
     * Method to get a list of columns of a database table.
     *
     * @param     string    $table  The name of the database table.
     *
     * @return    array
     */
    private function getTableColumns($table)
    {
        if (!isset(self::$tableColumns[$table])) {
            $columns = Factory::getDbo()->getTableColumns($table, false);

            self::$tableColumns[$table] = !empty($columns) ? $columns : [];
        }

        return self::$tableColumns[$table];
    }
}
