<?php

/**
 * @package    VP Email Manager
 * @copyright  Copyright (C) 2012-2024 VirtuePlanet Services LLP. All rights reserved.
 * @license    GNU General Public License version 3 or later; see LICENSE.txt
 * @author     Abhishek Das <info@virtueplanet.com>
 * @link       https://www.virtueplanet.com
 *
 * @phpcs:disable PSR1.Classes.ClassDeclaration.MissingNamespace
 */

use Joomla\CMS\Factory;
use Joomla\Registry\Registry;
use Joomla\CMS\Uri\Uri;

// phpcs:disable PSR1.Files.SideEffects
defined('_JEXEC') or die;
// phpcs:enable PSR1.Files.SideEffects

/**
 * Class VpemControllerCron
 */
class VpemControllerCron extends JControllerLegacy
{
    /**
     * Task to initiate the cron job
     *
     * @return void
     */
    public function run()
    {
        $options = new Registry(['follow_location' => true]);
        $adapter = JHttpFactory::getAvailableDriver($options);

        if ($adapter) {
            $url  = Uri::getInstance()->toString(['scheme', 'user', 'pass', 'host', 'port']);
            $url .= Uri::root(true) . '/';
            $url .= 'index.php?option=com_vpem';

            $post_uri  = JUri::getInstance($url);
            $post      = http_build_query(['task' => 'cron.runCronjob'], '', '&');
            $headers   = [];
            $userAgent = 'Email Manager for VirtueMart/cron-job';
            $response  = $adapter->request('POST', $post_uri, $post, $headers, 10, $userAgent);
        }

        header('Content-Type: image/gif');
        header('Content-Length: 43');
        header('Cache-Control: public,max-age=1,must-revalidate');
        header('Expires: ' . gmdate('D, d M Y H:i:s', ($_SERVER['REQUEST_TIME'] + 1)) . ' GMT');
        header('Last-modified: ' . gmdate('D, d M Y H:i:s', $_SERVER['REQUEST_TIME']) . ' GMT');

        if (function_exists('header_remove')) {
            header_remove('Pragma');
        }

        // 1 x 1 gif
        echo chr(0x47) . chr(0x49) . chr(0x46) . chr(0x38) . chr(0x39) . chr(0x61) . chr(0x01) . chr(0x00) .
            chr(0x01) . chr(0x00) . chr(0x80) . chr(0x00) . chr(0x00) . chr(0x04) . chr(0x02) . chr(0x04) .
            chr(0x00) . chr(0x00) . chr(0x00) . chr(0x21) . chr(0xF9) . chr(0x04) . chr(0x01) . chr(0x00) .
            chr(0x00) . chr(0x00) . chr(0x00) . chr(0x2C) . chr(0x00) . chr(0x00) . chr(0x00) . chr(0x00) .
            chr(0x01) . chr(0x00) . chr(0x01) . chr(0x00) . chr(0x00) . chr(0x02) . chr(0x02) . chr(0x44) .
            chr(0x01) . chr(0x00) . chr(0x3B);

        Factory::getApplication()->close();
    }

    /**
     * Run task method.
     *
     * @return  JController   This object to support chaining.
     * @throws  Exception
     */
    public function runCronjob()
    {
        $time_start = microtime(true);

        $model   = $this->getModel();
        $message = 'Cron job successful';

        if (!$model->run()) {
            $message = 'Cron job failed. Check log to learn more.';
        }

        echo '<h1>' . $message . '</h1>';

        $execution_time = (microtime(true) - $time_start);

        if ($execution_time < 1) {
            $execution_time = number_format(($execution_time * 1000), 2, '.', ',') . ' ms';
        } else {
            $execution_time = number_format($execution_time, 6, '.', ',') . ' s';
        }

        echo '<p><i>Execution Time: ' . $execution_time . '</i></p>';

        Factory::getApplication()->close();
    }

    /**
     * Proxy for getModel.
     *
     * @param   string  $name    Optional. Model name
     * @param   string  $prefix  Optional. Class prefix
     * @param   array   $config  Optional. Configuration array for model
     *
     * @return  object  The Model
     */
    public function getModel($name = 'Cron', $prefix = 'VpemModel', $config = ['ignore_request' => true])
    {
        return parent::getModel($name, $prefix, $config);
    }
}
