<?php

/**
 * @package    VP Email Manager
 * @copyright  Copyright (C) 2012-2024 VirtuePlanet Services LLP. All rights reserved.
 * @license    GNU General Public License version 3 or later; see LICENSE.txt
 * @author     Abhishek Das <info@virtueplanet.com>
 * @link       https://www.virtueplanet.com
 *
 * @phpcs:disable PSR1.Classes.ClassDeclaration.MissingNamespace
 */

// phpcs:disable PSR1.Files.SideEffects
defined('_JEXEC') or die;
// phpcs:enable PSR1.Files.SideEffects

class VpemShutdownScheduler
{
    private $callbacks; // array to store user callbacks

    public function __construct()
    {
        $this->callbacks = array();

        register_shutdown_function(array($this, 'callRegisteredShutdown'));
    }

    public function registerShutdownEvent()
    {
        $arguments = func_get_args();

        if (empty($arguments)) {
            trigger_error('No arguments passed to ' . __FUNCTION__ . ' method', E_USER_ERROR);

            return false;
        }

        if (!is_callable($arguments[1])) {
            trigger_error('Invalid callback passed to the ' . __FUNCTION__ . ' method', E_USER_ERROR);

            return false;
        }

        if (!is_string($arguments[0])) {
            trigger_error('Invalid event name passed to the ' . __FUNCTION__ . ' method', E_USER_ERROR);

            return false;
        }

        $eventName = $arguments[0];

        unset($arguments[0]);

        $this->callbacks[$eventName] = $arguments;

        return true;
    }

    public function unregisterShutdownEvent($eventName)
    {
        unset($this->callbacks[$eventName]);
    }

    public function callRegisteredShutdown()
    {
        foreach ($this->callbacks as $arguments) {
            $callback = array_shift($arguments);

            call_user_func_array($callback, $arguments);
        }
    }
}
