<?php

/**
 * @package    VP Email Manager
 * @copyright  Copyright (C) 2012-2024 VirtuePlanet Services LLP. All rights reserved.
 * @license    GNU General Public License version 3 or later; see LICENSE.txt
 * @author     Abhishek Das <info@virtueplanet.com>
 * @link       https://www.virtueplanet.com
 *
 * @phpcs:disable PSR1.Classes.ClassDeclaration.MissingNamespace
 */

use Joomla\CMS\Factory;
use Joomla\Registry\Registry;

// phpcs:disable PSR1.Files.SideEffects
defined('_JEXEC') or die;
// phpcs:enable PSR1.Files.SideEffects

/**
 * VpemModelCronjob model.
 */
class VpemModelCron extends JModelLegacy
{
    protected static $calls = 0;

    /**
     * @var   string  The prefix to use with controller messages.
     */
    protected $text_prefix = 'COM_VPEM';

    /**
     * Run cron job
     *
     * @return boolean
     */
    public function run()
    {
        $db                = $this->getDbo();
        $date              = Factory::getDate();
        $query             = $db->getQuery(true);
        $shutdownScheduler = new VpemShutdownScheduler();
        $vendorModel       = VmModel::getModel('vendor');

        $query->select('a.*')
            ->from($db->quoteName('#__vpem_events') . ' AS ' . $db->quoteName('a'))
            ->join('INNER', $db->quoteName('#__vpem_templates') . ' AS ' . $db->quoteName('t') . ' ON ' . $db->quoteName('t.id') . ' = ' . $db->quoteName('a.template_id'))
            ->where($db->quoteName('a.type') . ' = ' . $db->quote('order_followup'))
            ->where($db->quoteName('a.state') . ' = 1')
            ->where($db->quoteName('t.state') . ' = 1');

        $db->setQuery($query);
        $events = $db->loadObjectList();

        foreach ($events as $event) {
            $orderStatuses = [];

            if ($event->filter_status && strpos($event->filter_status, '{') !== false) {
                $temp          = new Registry($event->filter_status);
                $orderStatuses = $temp->toArray();
            } elseif ($event->filter_status) {
                $orderStatuses[] = $event->filter_status;
            }

            // If no order status filter is set.
            if (empty($orderStatuses) || empty($event->interval_uom)) {
                continue;
            }

            $startDate = (int) $event->followup_starts_on > 0 ? $event->followup_starts_on : null;
            $intervals = new Registry($event->intervals);
            $date      = Factory::getDate();

            $date->modify('-' . $intervals->get($event->interval_uom, 1) . ' ' . $event->interval_uom);

            $query->clear()
                ->select('DISTINCT ' . $db->quoteName('o.virtuemart_order_id'))
                ->select($db->quoteName('o.virtuemart_vendor_id'))
                ->select($db->quoteName('u.email'))
                ->select($db->quoteName('of.id'))
                ->from($db->quoteName('#__virtuemart_orders') . ' AS ' . $db->quoteName('o'))
                ->join('INNER', $db->quoteName('#__virtuemart_order_userinfos') . ' AS ' . $db->quoteName('u') . ' ON ' . $db->quoteName('u.virtuemart_order_id') . ' = ' . $db->quoteName('o.virtuemart_order_id') . ' AND ' . $db->quoteName('u.address_type') . ' = ' . $db->quote('BT'))
                ->join('LEFT', $db->quoteName('#__vpem_followups') . ' AS ' . $db->quoteName('of') . ' ON ' . $db->quoteName('of.order_id') . ' = ' . $db->quoteName('o.virtuemart_order_id') . ' AND ' . $db->quoteName('of.event_id') . ' = ' . $event->id);

            if (count($orderStatuses) === 1) {
                $query->where($db->quoteName('o.order_status') . ' = ' . $db->quote($orderStatuses[0]));
            } else {
                /** @disregard P1009 */
                $query->where($db->quoteName('o.order_status') . ' IN (' . implode(',', $db->quote($orderStatuses)) . ')');
            }

            $query->where('CASE WHEN ' . $db->quoteName('o.modified_on') . ' = ' . $db->quote('0000-00-00 00:00:00') . ' OR ' . $db->quoteName('o.modified_on') . ' IS NULL THEN ' . $db->quoteName('o.created_on') . ' <= ' . $db->quote($date->toSql()) . ' ELSE ' . $db->quoteName('o.modified_on') . ' <= ' . $db->quote($date->toSql()) . ' END');

            if ($startDate) {
                $query->where('CASE WHEN ' . $db->quoteName('o.modified_on') . ' = ' . $db->quote('0000-00-00 00:00:00') . ' OR ' . $db->quoteName('o.modified_on') . ' IS NULL THEN ' . $db->quoteName('o.created_on') . ' >= ' . $db->quote($startDate) . ' ELSE ' . $db->quoteName('o.modified_on') . ' >= ' . $db->quote($startDate) . ' END');
            }

            $subQuery = $db->getQuery(true);

            $subQuery->select($db->quoteName('f.order_id'))
                ->from($db->quoteName('#__vpem_followups') . ' AS ' . $db->quoteName('f'))
                ->where('(' . $db->quoteName('f.status') . ' = 1 OR ' . $db->quoteName('f.status') . ' = -1)')
                ->where($db->quoteName('f.event_id') . ' = ' . $event->id);

            $query->where($db->quoteName('o.virtuemart_order_id') . ' NOT IN (' . $subQuery . ')');

            $db->setQuery($query);
            $orders = $db->loadObjectList();

            foreach ($orders as $order) {
                $virtuemart_vendor_id = empty($order->virtuemart_vendor_id) ? 1 : $order->virtuemart_vendor_id;
                $order->vendor        = $vendorModel->getVendor($virtuemart_vendor_id);
                $order->vendorEmail   = $vendorModel->getVendorEmail($virtuemart_vendor_id);

                // Set followup status as running.
                $pk = $this->setCronRunning($order->id, $order->virtuemart_order_id, $event->id);

                // Build an unique event name
                $eventName = 'clearRunning-' . $order->virtuemart_order_id;

                // Registered the shutdown function incase execution times out
                $shutdownScheduler->registerShutdownEvent($eventName, array($this, 'clearCronRunning'), $pk);

                // Try to send the mail.
                $result = VpemHelper::sendMail('order_followup', $order, $order->email, false, $event->id);

                self::$calls++;

                if ($result === false) {
                    $this->clearCronRunning($pk);
                } else {
                    $this->setCronSuccess($pk);
                }

                // Unregister shutdown function
                $shutdownScheduler->unregisterShutdownEvent($eventName);
            }
        }

        return true;
    }

    public function setCronRunning($id, $orderId, $eventId)
    {
        $db = $this->getDbo();

        $data = new stdClass();

        $data->id       = (int) $id;
        $data->order_id = (int) $orderId;
        $data->event_id = (int) $eventId;
        $data->status   = -1;
        $data->sent_on  = '0000-00-00 00:00:00';

        if ($data->id > 0) {
            $db->updateObject('#__vpem_followups', $data, 'id', false);
        } else {
            $db->insertObject('#__vpem_followups', $data, 'id');
        }

        return $data->id;
    }

    public function clearCronRunning($id)
    {
        $db    = $this->getDbo();
        $query = $db->getQuery(true);

        $query->update($db->quoteName('#__vpem_followups'))
            ->set($db->quoteName('status') . ' = 0')
            ->where($db->quoteName('id') . ' = ' . $id);

        $db->setQuery($query);
        $db->execute();
    }

    public function setCronSuccess($id)
    {
        $db    = $this->getDbo();
        $query = $db->getQuery(true);
        $date  = Factory::getDate();

        $query->update($db->quoteName('#__vpem_followups'))
            ->set($db->quoteName('status') . ' = 1')
            ->set($db->quoteName('sent_on') . ' = ' . $db->quote($date->toSql()))
            ->where($db->quoteName('id') . ' = ' . $id);

        $db->setQuery($query);
        $db->execute();
    }
}
